@@ -31,6 +31,7 @@
 
 #include <genht/htip.h>
 #include <genht/htsp.h>
+#include <genht/htpp.h>
 
 #include "libcschem/common_types.h"
 #include "libcschem/attrib.h"
@@ -53,6 +54,9 @@ struct csch_abstract_s {
 	unsigned new_comps:1; /* set to 1 whe a new component is created */
 	unsigned new_nets:1;  /* set to 1 whe a new net is created */
 	unsigned new_ports:1; /* set to 1 whe a new port is created */
+	csch_project_t *prj;  /* only during compilation */
+	long view_id;         /* which view the abstract model is compiled for; only during compilation */
+	htpp_t eng_transient; /* private data used during compilation by engines; typically set in the project_before hook and removed/freed in the project_after hook; key is a const char *cookie */
 };
 
 typedef enum csch_atype_e {
@@ -76,6 +80,10 @@ struct csch_ahdr_s {
 	csch_abstract_t *abst;
 	const char *ghost;        /* if not NULL, the given object is only an empty shell (got used once during the compilation, but was emptied later, probably merged into something else) */
 	unsigned compiled:1;      /* already compiled, compiler should skip it */
+
+	/* cached from attributes to speed up render */
+	unsigned dnp:1;           /* attribute display/dnp: do not populate */
+	unsigned omit:1;          /* attribute display/dnp: omit from export */
 };
 
 typedef struct csch_acomp_s csch_acomp_t;
