@@ -81,6 +81,7 @@ static void attr_free(csch_attrib_t *a)
 	free(a->key);
 	attr_free_val(a);
 	attr_free_vts(&a->source);
+	free(a->export_name);
 	free(a);
 }
 
@@ -211,7 +212,7 @@ int csch_attrib_seti(csch_attribs_t *attribs, int prio, const char *key, long id
 	return -1;
 }
 
-/* how is: 0=overwrite whole arr; -1=prepend; +1=append */
+/* how is: 0=overwrite whole arr; -1=prepend; +1=append; does not free src */
 static int csch_attrib_set_arr_nofree(csch_attribs_t *attribs, int prio, const char *key, const vts0_t *val, csch_source_arg_t *source, csch_attrib_t **attr_out, int how)
 {
 	long n;
@@ -315,6 +316,11 @@ int csch_attrib_set_arr_c(csch_attribs_t *attribs, int prio, const char *key, co
 	return res;
 }
 
+void csch_attrib_set_export_name(csch_attrib_t *dst, const char *expname)
+{
+	free(dst->export_name);
+	dst->export_name = rnd_strdup(expname);
+}
 
 csch_attrib_t *csch_attrib_dup(csch_attrib_t *src)
 {
@@ -369,35 +375,84 @@ void csch_attrib_copy_all(csch_attribs_t *dst, const csch_attribs_t *src)
 	}
 }
 
-void csch_attrib_copy_all_undoable(csch_sheet_t *sheet, csch_cgrp_t *dst_obj, const csch_attribs_t *src)
+static csch_source_arg_t *attr_copy_gen_source(csch_attrib_t *s)
+{
+	char *sep, *ssrc = s->source.array[0];
+	long len;
+	csch_source_arg_t *src;
+
+	sep = strchr(ssrc, ':');
+	sep++;
+	len = strlen(sep);
+
+	src = malloc(sizeof(csch_source_arg_t) + len + 1);
+	src->type[0] = 'c';
+	src->type[1] = '\0';
+	memcpy(src->src_desc, sep, len+1);
+
+	return src;
+}
+
+void csch_attrib_copy_all_undoable(csch_sheet_t *sheet, csch_cgrp_t *dst_obj, csch_attribs_t *dst, const csch_attribs_t *src, int undoable)
 {
 	htsp_entry_t *e;
-	csch_attribs_t *dst = &dst_obj->attr;
+
+	assert((dst != NULL) || (dst_obj != NULL));
+
+	if (undoable) {
+		assert(dst_obj != NULL);
+		assert(sheet != NULL);
+	}
+
+	if (dst == NULL)
+		dst = &dst_obj->attr;
 
 	for(e = htsp_first(src); e; e = htsp_next(src, e)) {
 		csch_attrib_t *s = csch_attrib_dup(e->value);
 		csch_attrib_t *d = csch_attrib_get(dst, e->key);
-		if (s->val == NULL) {
-TODO("figure how to merge arrays");
-			rnd_message(RND_MSG_ERROR, "csch_attrib_copy_all_undoable(): internal error: can't copy/merge arrya type attribte '%s'\n", e->key);
+
+		if ((s != NULL) && (d != NULL) && (csch_attrib_val_eq_(s, d))) continue; /* do not merge if values are the same */
+
+		if (s->val == NULL) { /* source is an array */
+			int done = 0;
+
+			if (s->arr.used > 0) {
+				if ((d == NULL) || ((d->arr.used == 0) && (d->val == NULL))) {
+					/* source has an array, destination has nothing: simply copy the array */
+					long n;
+
+					if (undoable) {
+						if (d == NULL) {
+							d = attr_alloc(e->key, s->prio);
+							htsp_set(dst, e->key, d);
+						}
+						vts0_append(&d->arr, NULL); /* dummy cursor for insert before */
+						for(n = 0; n < s->arr.used; n++)
+							csch_attr_arr_modify_ins_before(sheet, dst_obj, e->key, n, s->arr.array[n], 1);
+						d->arr.used--; /* remove dummy cursor */
+						done = 1;
+					}
+					else {
+						csch_source_arg_t *source = attr_copy_gen_source(s);
+						csch_attrib_set_arr(dst, s->prio, e->key, &s->arr, source, NULL);
+						done = 1;
+					}
+				}
+			}
+
+TODO("figure how to merge arrays with differing content");
+			if (!done)
+				rnd_message(RND_MSG_ERROR, "csch_attrib_copy_all_undoable(): internal error: can't copy/merge array type attribte '%s'\n", e->key);
 		}
-		else {
-TODO("handle if src is an array");
-			if ((d == NULL) || ((d->val != NULL) && (strcmp(d->val, s->val) != 0))) {
-				char *sep, *ssrc = s->source.array[0];
-				long len;
-				csch_source_arg_t *src;
+		else { /* source is scalar */
+TODO("handle if dst is an array");
+			if ((d == NULL) || ((d->val != NULL))) {
+				csch_source_arg_t *source = attr_copy_gen_source(s);
 
-				sep = strchr(ssrc, ':');
-				sep++;
-				len = strlen(sep);
-
-				src = malloc(sizeof(csch_source_arg_t) + len + 1);
-				src->type[0] = 'c';
-				src->type[1] = '\0';
-				memcpy(src->src_desc, sep, len+1);
-
-				csch_attr_modify_str(sheet, dst_obj, s->prio, e->key, s->val, src, 1);
+				if (undoable)
+					csch_attr_modify_str(sheet, dst_obj, s->prio, e->key, s->val, source, 1);
+				else
+					csch_attrib_set(dst, s->prio, e->key, s->val, source, NULL);
 			}
 		}
 	}
@@ -482,13 +537,10 @@ unsigned csch_attrib_hash(const csch_attribs_t *attr)
 	return res;
 }
 
-int csch_attrib_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2)
+int csch_attrib_val_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2)
 {
 	long n;
 
-	/* assume keys match */
-	if (a1->prio != a2->prio) return 0;
-	if (a1->deleted != a2->deleted) return 0;
 	if (a1->val != NULL) {
 		if (a2->val == NULL) return 0;
 		if (strcmp(a1->val, a2->val) != 0) return 0;
@@ -509,6 +561,15 @@ int csch_attrib_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2)
 	return 1;
 }
 
+int csch_attrib_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2)
+{
+	/* assume keys match */
+	if (a1->prio != a2->prio) return 0;
+	if (a1->deleted != a2->deleted) return 0;
+
+	return csch_attrib_val_eq_(a1, a2);
+}
+
 int csch_attrib_eq(const csch_attribs_t *attr1, const csch_attribs_t *attr2)
 {
 	htsp_entry_t *e;
@@ -759,7 +820,7 @@ RND_INLINE void attr_arr_del(csch_attrib_t *a, long idx)
 	a->arr.used--;
 }
 
-/* create a new, empty slot at [idx], oving all items starting from
+/* create a new, empty slot at [idx], moving all items starting from
    idx to +1. Effectively inserts an empty slot at idx, before the
    item that was at idx. */
 RND_INLINE void attr_arr_ins_before(csch_attrib_t *a, long idx)
@@ -839,7 +900,8 @@ static void undo_attr_arr_modify_free(void *udata)
 	undo_attr_arr_modify_t *u = udata;
 	free(u->key);
 	u->key = NULL;
-	free(u->newval);
+	if (u->newval != NEWVAL_DEL)
+		free(u->newval);
 	u->newval = NULL;
 	free(u->saved);
 	u->saved = NULL;
