@@ -48,6 +48,8 @@ typedef struct csch_attrib_s {
 	char *val;  /* scalar; if NULL, use arr */
 	vts0_t arr;
 	vts0_t source;
+
+	char *export_name; /* abstract model: if not NULL, export this attribute using this name (always strdup'd) */
 } csch_attrib_t;
 
 /* Opaque struct for temporarily holding attribute source information */
@@ -101,6 +103,7 @@ RND_INLINE const vts0_t *csch_attrib_get_arr(const csch_attribs_t *attribs, cons
 int csch_attrib_set(csch_attribs_t *attribs, int prio, const char *key, const char *val, csch_source_arg_t *source, csch_attrib_t **attr_out);
 int csch_attrib_setptr(csch_attribs_t *attribs, int prio, char *key, const char *val, csch_source_arg_t *source, csch_attrib_t **attr_out);
 
+/* Overwrite an array; src is always free'd. Items are strdup'd */
 int csch_attrib_set_arr(csch_attribs_t *attribs, int prio, const char *key, const vts0_t *val, csch_source_arg_t *source, csch_attrib_t **attr_out);
 int csch_attrib_set_arr_c(csch_attribs_t *attribs, int prio, const char *key, const char **val, csch_source_arg_t *source, csch_attrib_t **attr_out);
 
@@ -128,12 +131,17 @@ int csch_attrib_del(csch_attribs_t *attribs, int prio, const char *key, csch_sou
    (const csch_attrib_t *) */
 void csch_attrib_sort(vtp0_t *dst, const csch_attribs_t *attribs);
 
-/* Allocate a new attribute, duplicate src with all sources (deep copy) */
+/* Overwrites the export name from expname */
+void csch_attrib_set_export_name(csch_attrib_t *dst, const char *expname);
+
+
+/* Allocate a new attribute, duplicate src with all sources (deep copy); does
+   not copy export name. */
 csch_attrib_t *csch_attrib_dup(csch_attrib_t *src);
 
 /* copy each src attrib to dst */
 void csch_attrib_copy_all(csch_attribs_t *dst, const csch_attribs_t *src);
-void csch_attrib_copy_all_undoable(csch_sheet_t *sheet, csch_cgrp_t *dst_obj, const csch_attribs_t *src);
+void csch_attrib_copy_all_undoable(csch_sheet_t *sheet, csch_cgrp_t *dst_obj, csch_attribs_t *dst, const csch_attribs_t *src, int undoable);
 
 /* copy each src attrib to dst using a forced source; returns 0 on success;
    src is always free'd. If force_prio is not NULL, use that as the new
@@ -143,6 +151,7 @@ int csch_attrib_apply(csch_attribs_t *dst, const csch_attribs_t *src, csch_sourc
 unsigned csch_attrib_hash(const csch_attribs_t *attr);
 int csch_attrib_eq(const csch_attribs_t *a1, const csch_attribs_t *a2);
 int csch_attrib_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2);
+int csch_attrib_val_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2);
 
 
 /* Standard undoable mod functions; negative prio means: keep original if
