@@ -442,6 +442,19 @@ static void compile_reset_abstract(csch_abstract_t *dst)
 	dst->ucnt.target_tmp = 0;
 }
 
+static void csch_reset_sheet_aids(const csch_sheet_t *src)
+{
+	const csch_chdr_t *h;
+
+	for(h = gdl_first(&src->active); h != NULL; h = gdl_next(&src->active, h)) {
+		if (csch_obj_is_grp(h)) {
+			csch_cgrp_t *grp = (csch_cgrp_t *)h;
+			grp->aid.used = 0;
+		}
+	}
+}
+
+
 static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_sheet_t *src)
 {
 	int res = 0;
@@ -455,13 +468,7 @@ static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_shee
 		return src->non_graphical_impl->compile_sheet(dst, viewid, src);
 	}
 
-	/* reset aid */
-	for(h = gdl_first(&src->active); h != NULL; h = gdl_next(&src->active, h)) {
-		if (csch_obj_is_grp(h)) {
-			csch_cgrp_t *grp = (csch_cgrp_t *)h;
-			grp->aid.used = 0;
-		}
-	}
+	csch_reset_sheet_aids(src);
 
 	/* compile nets and components */
 	for(h = gdl_first(&src->active); h != NULL; h = gdl_next(&src->active, h)) {
@@ -544,7 +551,10 @@ RND_INLINE int csch_compile_post_comp(csch_project_t *proj, int viewid, csch_abs
 	if (comp->hdr.compiled) return 0;
 	comp->hdr.compiled = 1;
 
+	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT0, FGW_AOBJ, comp, FGW_INVALID);
+	csch_compile_update_obj_cache(&comp->hdr);
 	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT1, FGW_AOBJ, comp, FGW_INVALID);
+	csch_compile_update_obj_cache(&comp->hdr);
 
 	restart_port:;
 	dst->new_ports = 0;
@@ -567,6 +577,47 @@ RND_INLINE int csch_compile_post_net(csch_project_t *proj, int viewid, csch_abst
 	return dst->new_nets;
 }
 
+RND_INLINE void csch_compile_post_update_cache_(csch_ahdr_t *obj)
+{
+	const char *val;
+
+	val = csch_attrib_get_str(&obj->attr, "display/dnp");
+	if ((val != NULL) && (*val != '\0'))
+		obj->dnp = 1;
+
+	val = csch_attrib_get_str(&obj->attr, "display/omit");
+	if ((val != NULL) && (*val != '\0'))
+		obj->omit = 1;
+}
+
+void csch_compile_update_obj_cache(csch_ahdr_t *obj)
+{
+	csch_compile_post_update_cache_(obj);
+}
+
+
+/* Calculate all caches in the abstract model after the compilation has finished */
+RND_INLINE void csch_compile_post_update_cache(csch_project_t *proj, int viewid, csch_abstract_t *abst)
+{
+	htsp_entry_t *n, *c, *p;
+
+	for(n = htsp_first(&abst->nets); n != NULL; n = htsp_next(&abst->nets, n)) {
+		csch_anet_t *net = n->value;
+		csch_compile_post_update_cache_(&net->hdr);
+	}
+
+
+	for(c = htsp_first(&abst->comps); c != NULL; c = htsp_next(&abst->comps, c)) {
+		csch_acomp_t *comp = c->value;
+		csch_compile_post_update_cache_(&comp->hdr);
+		for(p = htsp_first(&comp->ports); p != NULL; p = htsp_next(&comp->ports, p)) {
+			csch_aport_t *port = p->value;
+			csch_compile_post_update_cache_(&port->hdr);
+		}
+	}
+
+}
+
 int csch_compile_post(csch_project_t *proj, int viewid, csch_abstract_t *dst)
 {
 	htsp_entry_t *e;
@@ -589,6 +640,8 @@ int csch_compile_post(csch_project_t *proj, int viewid, csch_abstract_t *dst)
 	csch_eng_call(proj, viewid, CSCH_ENGHK_PROJECT_AFTER,
 		FGW_PTR, dst, FGW_PTR, proj, FGW_INVALID);
 
+	csch_compile_post_update_cache(proj, viewid, dst);
+
 	sheet = *vtp0_get(&proj->hdr.designs, 0, 0);
 	rnd_event(&sheet->hidlib, CSCH_EVENT_PRJ_COMPILED, NULL);
 	return 0;
@@ -598,8 +651,12 @@ int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst,
 {
 	int res = 0, r;
 	long n;
+	htpp_entry_t *e;
 
 	compile_reset_abstract(dst);
+	htpp_init(&dst->eng_transient, ptrhash, ptrkeyeq);
+	dst->view_id = viewid;
+	dst->prj = prj;
 
 	if (csch_project_is_partial(prj))
 		rnd_message(RND_MSG_ERROR, "*** PARTIAL PROJECT ***\nNot all root sheets are loaded, the resulting abstract model\nwill be partial too.\n");
@@ -615,6 +672,8 @@ int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst,
 		if ((sheet->stype == CSCH_SHTY_UNLISTED) || (sheet->stype == CSCH_SHTY_unknown)) {
 			if (prj->num_root_sheets != 0) {
 				rnd_message(RND_MSG_WARNING, "Compile: not compiling sheet %s: unlisted file in a project with explicit sheet list in project file\n", sheet->hidlib.loadname);
+				if (!sheet->non_graphical)
+					csch_reset_sheet_aids(sheet);
 				continue;
 			}
 			else {
@@ -628,5 +687,10 @@ int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst,
 		res |= r;
 	}
 	csch_compile_post(prj, viewid, dst);
+	
+	for(e = htpp_first(&dst->eng_transient); e != NULL; e = htpp_next(&dst->eng_transient, e))
+		rnd_message(RND_MSG_ERROR, "csch_compile_project(): engine transient leftover: %s (memory leak)\n", e->key);
+	htpp_uninit(&dst->eng_transient);
+	dst->prj = NULL;
 	return res;
 }
