@@ -55,6 +55,11 @@ int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attr
 int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_reconn);
 int csch_compile_disconnect(csch_ahdr_t *a);
 
+/* Updates hdr cache fields, e.g. dnp and omit, from attributes; useful after
+   setting such an attribute or before depending on such an attribute */
+void csch_compile_update_obj_cache(csch_ahdr_t *obj);
+
+
 /*** for lib itnernal use ***/
 
 RND_INLINE void csch_compile_add_source(csch_cgrp_t *src, csch_ahdr_t *abst)
