@@ -290,6 +290,11 @@ csch_oid_t csch_oid_new(csch_sheet_t *sheet, csch_cgrp_t *grp);
 /* Return the human readable name of a display layer, or "<invalid>" */
 const char *csch_dsply_name(csch_displayer_t dsply);
 
+/* Return the sheet's rtree for a name; the name may be suffixed with
+   -fill or -stroke for selecting the appropriate rtree. If not suffixed,
+   the stroke rtree is returned. */
+csch_rtree_t *csch_rtree_lookup_by_name(csch_sheet_t *sheet, const char *name);
+
 /* Return the human readable name of concrete object type, or "<invalid>" */
 const char *csch_ctype_name(csch_ctype_t typ);
 
