@@ -37,11 +37,12 @@ typedef enum {
 	CSCH_ENGHK_TERMINAL_NAME_TO_PORT_NAME,
 	CSCH_ENGHK_SYMBOL_NAME_TO_COMPONENT_NAME,
 	CSCH_ENGHK_SYMBOL_JOINED_COMPONENT,
-	CSCH_ENGHK_COMPILE_COMPONENT1,
-	CSCH_ENGHK_COMPILE_COMPONENT2,
+	CSCH_ENGHK_COMPILE_COMPONENT0, /* called once per component, after all symbol merges, before port processing; should set component attributes but should not have any other side effect (e.g. making connections) */
+	CSCH_ENGHK_COMPILE_COMPONENT1, /* same as component0, but can have side effects */
+	CSCH_ENGHK_COMPILE_COMPONENT2, /* called once per component, after port merges finished */
 	CSCH_ENGHK_COMPILE_PORT,
 	CSCH_ENGHK_COMPILE_NET,
-	CSCH_ENGHK_CONNS_BEFORE,  /* called once per sheet, before starinh to compile connection objects */
+	CSCH_ENGHK_CONNS_BEFORE,  /* called once per sheet, before starting to compile connection objects */
 	CSCH_ENGHK_CONNS_AFTER,   /* called once per sheet, after finished compiling connection objects */
 	CSCH_ENGHK_PROJECT_BEFORE, /* called once before starting to compile the project */
 	CSCH_ENGHK_PROJECT_AFTER, /* called once after finished compiling the project */
