@@ -46,7 +46,8 @@ static void igy_brk() {}
 #define ASSERT(expr, reason) \
 	do { \
 		if (!(expr)) { \
-			rnd_message(RND_MSG_ERROR,  "Integrity violation: " reason " (" #expr ") at " CSCH_IGY_LOC  ", called from: %s\n", called_from); \
+			const char *sheetname = sheet->hidlib.loadname; \
+			rnd_message(RND_MSG_ERROR,  "Integrity violation: " reason " (" #expr ") at " CSCH_IGY_LOC  ", sheet: %s; called from: %s\n", sheetname, called_from); \
 			igy_brk(); \
 			res |= 1; \
 		} \
@@ -94,6 +95,7 @@ RND_INLINE int igy_cnc_conn(void *parent, csch_conn_t *c, const char *called_fro
 RND_INLINE int igy_cnc_obj(csch_cgrp_t *parent, csch_chdr_t *obj, const char *called_from)
 {
 	int res = 0;
+	csch_sheet_t *sheet = obj->sheet;
 
 	if (parent != NULL)
 		ASSERT(parent == obj->parent, "broken object parent");
@@ -157,6 +159,7 @@ RND_INLINE int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_fro
 {
 	int res = 0;
 	long wnlen = htip_length(&wn->id2obj);
+	csch_sheet_t *sheet = wn->hdr.sheet;
 
 	if (wnlen > 1) {
 		htip_entry_t *e;
@@ -210,6 +213,7 @@ RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_fr
 {
 	int res = 0;
 	htip_entry_t *e;
+	csch_sheet_t *sheet = grp->hdr.sheet;
 
 	if (parent != NULL)
 		ASSERT(parent == grp->hdr.parent, "broken group parent");
@@ -242,6 +246,7 @@ RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_fr
 RND_INLINE int igy_cnc_direct(csch_cgrp_t *grp, const char *called_from)
 {
 	int res = 0;
+	csch_sheet_t *sheet = grp->hdr.sheet;
 
 	ASSERT(grp->spec_rot == 0, "sheet's direct group must not be rotated");
 	ASSERT(grp->x == 0, "sheet's direct group must not be translated (x)");
@@ -252,6 +257,29 @@ RND_INLINE int igy_cnc_direct(csch_cgrp_t *grp, const char *called_from)
 	return res;
 }
 
+RND_INLINE int igy_cnc_rtree(csch_sheet_t *sheet, csch_rtree_t *rtree, const char *called_from)
+{
+	csch_rtree_it_t it;
+	csch_chdr_t *o;
+	int res = 0;
+
+	for(o = csch_rtree_all_first(&it, rtree); o != NULL; o = csch_rtree_all_next(&it)) {
+		ASSERT(!csch_obj_is_deleted(o), "Ghost object: presents in rtree but has been deleted");
+	}
+
+	return res;
+}
+
+RND_INLINE int igy_cnc_rtrees(csch_sheet_t *sheet, const char *called_from)
+{
+	int n, res = 0;
+	for(n = 0; n < CSCH_DSPLY_max; n++) {
+		res |= igy_cnc_rtree(sheet, &sheet->dsply[n], called_from);
+		res |= igy_cnc_rtree(sheet, &sheet->dsply_fill[n], called_from);
+	}
+	return res;
+}
+
 RND_INLINE int igy_sheet(csch_project_t *proj, csch_sheet_t *sheet, const char *called_from)
 {
 	int res = 0;
@@ -269,6 +297,7 @@ RND_INLINE int igy_sheet(csch_project_t *proj, csch_sheet_t *sheet, const char *
 
 	res |= igy_cnc_grp(NULL, &sheet->direct, called_from);
 	res |= igy_cnc_grp(NULL, &sheet->indirect, called_from);
+	res |= igy_cnc_rtrees(sheet, called_from);
 
 	return res;
 }
