@@ -40,6 +40,7 @@
 #include "integrity.h"
 #include "undo.h"
 #include "actions_csch.h"
+#include "drc.h"
 
 const int *csch_cfg_multiport_net_merge = NULL;
 minuid_session_t csch_minuid;
@@ -60,6 +61,7 @@ void csch_uninit(void)
 	csch_project_uninit();
 	csch_project_act_uninit();
 	csch_integrity_act_uninit();
+	csch_drc_act_uninit();
 	csch_undo_act_uninit();
 	csch_plug_library_uninit();
 }
@@ -69,6 +71,7 @@ int csch_init_actions()
 	csch_actions_init(&rnd_fgw); /* custom fgw types */
 	csch_project_act_init();
 	csch_integrity_act_init();
+	csch_drc_act_init();
 	csch_undo_act_init();
 	csch_project_init();
 	return 0;
