@@ -263,7 +263,6 @@ int csch_test_parse_fn(rnd_design_t *hl, const char *fn, csch_plug_io_type_t typ
 void *csch_test_parse_bundled(rnd_design_t *hl, const char *real_fn, csch_plug_io_type_t type, FILE **f_out, void **io_out)
 {
 	long n;
-	int res = 0;
 	FILE *f = NULL;
 	void *cookie = NULL;
 
@@ -482,7 +481,12 @@ csch_project_t *csch_load_project(const char *load_fn, const char *fmt, int with
 	return proj;
 }
 
-typedef enum { SS_SAVE_SHEET, SS_SAVE_SHEET_BACKUP, SS_EXPORT_SHEET, SS_SAVE_BUFFER } save_sheet_t;
+static int csch_save_sheet_as_sym(prio_t *pr, const char *fn, const char *fmt, const csch_sheet_t *sheet)
+{
+	return pr->io->save_grp(fn, fmt, &sheet->direct, 0);
+}
+
+typedef enum { SS_SAVE_SHEET, SS_SAVE_SHEET_BACKUP, SS_EXPORT_SHEET, SS_SAVE_BUFFER, SS_SAVE_SHEET_AS_SYM } save_sheet_t;
 static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const char *fmt, save_sheet_t stype, int preserve_changed)
 {
 	vtpr_t prios;
@@ -492,6 +496,9 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 	if ((fmt == NULL) || (*fmt == '\0'))
 		return -1;
 
+	if (sheet->is_symbol && ((stype == SS_SAVE_SHEET) || (stype == SS_SAVE_SHEET_BACKUP)))
+		stype = SS_SAVE_SHEET_AS_SYM;
+
 	len = strlen(fn_);
 	fn = malloc(len+1);
 	memcpy(fn, fn_, len+1);
@@ -517,6 +524,12 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 					else
 						*ext = '\0';
 					break;
+				case SS_SAVE_SHEET_AS_SYM:
+					if (pr->io->ext_save_grp != NULL)
+						strcpy(ext, pr->io->ext_save_grp);
+					else
+						*ext = '\0';
+					break;
 				case SS_SAVE_BUFFER:
 					if (pr->io->ext_save_buffer != NULL)
 						strcpy(ext, pr->io->ext_save_buffer);
@@ -533,10 +546,16 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 				break;
 			case SS_SAVE_SHEET:
 			case SS_SAVE_SHEET_BACKUP:
+			case SS_SAVE_SHEET_AS_SYM:
 				sheet->saving = 1;
 				rnd_event(&sheet->hidlib, RND_EVENT_SAVE_PRE, "s", fmt);
-				ret = pr->io->save_sheet(fn, fmt, sheet);
-				if (stype == SS_SAVE_SHEET) {
+
+				if (stype == SS_SAVE_SHEET_AS_SYM)
+					ret = csch_save_sheet_as_sym(pr, fn, fmt, sheet);
+				else
+					ret = pr->io->save_sheet(fn, fmt, sheet);
+
+				if ((stype == SS_SAVE_SHEET) || (stype == SS_SAVE_SHEET_AS_SYM)) {
 					char *newname = rnd_lrealpath(fn);
 					if ((sheet->hidlib.fullpath == NULL) || (strcmp(sheet->hidlib.fullpath, newname) != 0)) {
 						free(sheet->hidlib.fullpath);
@@ -554,6 +573,7 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 				if ((ret == 0) && !preserve_changed)
 					csch_sheet_set_changed(sheet, 0);
 				break;
+
 			case SS_SAVE_BUFFER:
 				ret = pr->io->save_buffer(fn, fmt, sheet);
 				break;
@@ -584,7 +604,7 @@ int csch_save_sheet_backup(csch_sheet_t *sheet, const char *fn, const char *fmt)
 }
 
 
-int csch_export_project_abst(csch_abstract_t *abs, const char *fn_, const char *fmt)
+int csch_export_project_abst(csch_abstract_t *abs, const char *fn_, const char *fmt, rnd_hid_attr_val_t *options)
 {
 	vtpr_t prios;
 	int n, ret = -1, len;
@@ -609,7 +629,7 @@ int csch_export_project_abst(csch_abstract_t *abs, const char *fn_, const char *
 			else
 				*ext = '\0';
 		}
-		ret = pr->io->export_project_abst(fn, fmt, abs);
+		ret = pr->io->export_project_abst(fn, fmt, abs, options);
 		if (ret == 0)
 			break;
 	}
@@ -619,7 +639,7 @@ int csch_export_project_abst(csch_abstract_t *abs, const char *fn_, const char *
 	return ret;
 }
 
-int csch_save_grp(csch_cgrp_t *grp, const char *fn_, const char *fmt)
+int csch_save_grp(csch_cgrp_t *grp, const char *fn_, const char *fmt, int inhibit_uuid)
 {
 	vtpr_t prios;
 	int n, ret = -1, len;
@@ -644,7 +664,7 @@ int csch_save_grp(csch_cgrp_t *grp, const char *fn_, const char *fmt)
 			else
 				*ext = '\0';
 		}
-		ret = pr->io->save_grp(fn, fmt, grp);
+		ret = pr->io->save_grp(fn, fmt, grp, inhibit_uuid);
 		if (ret == 0)
 			break;
 	}
