@@ -103,7 +103,7 @@ void csch_lib_remove(csch_lib_t *l)
 
 
 
-RND_INLINE char *slib_find_realpath(rnd_design_t *hl, csch_lib_master_t *master, char *path, const csch_lib_backend_t **be_out)
+RND_INLINE char *slib_find_realpath(rnd_design_t *hl, csch_lib_master_t *master, const char *path, const csch_lib_backend_t **be_out)
 {
 	long n;
 
@@ -163,7 +163,7 @@ RND_INLINE csch_lib_t *csch_lib_map(rnd_design_t *hl, csch_lib_master_t *master,
 	return res;
 }
 
-int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int append)
+int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int append, int do_rehash, int skip_just_mapped)
 {
 	rnd_design_t *hl = &sheet->hidlib;
 	csch_lib_root_t *libroot;
@@ -173,13 +173,19 @@ int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int
 	int optional = (*path == '?');
 
 	if (real_path == NULL) {
-		if (optional)
+		if (optional) {
+			free(path); path = NULL;
 			return 0;
-		rnd_message(RND_MSG_ERROR, "Symbol library mapping error: no plugin to handle '%s'\n", path);
+		}
+		rnd_message(RND_MSG_ERROR, "Symbol library mapping error: no plugin to handle '%s' (or plugin failed to map it, e.g. path does not exist)\n", path);
+		free(path); path = NULL;
 		return -1;
 	}
 
 	root = htsp_get(&master->roots, real_path);
+	if ((root != NULL) && skip_just_mapped && root->just_mapped)
+		do_rehash = 0;
+
 	if (root == NULL) {
 		/* need to map be_new */
 		root = csch_lib_map(hl, master, be_new, path, real_path);
@@ -189,20 +195,30 @@ int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int
 #if 0
 			if (real_path != path) free(real_path);
 			rnd_message(RND_MSG_ERROR, "Symbol library mapping error: %s failed to map '%s'\n", be_new->name, path);
+			free(path); path = NULL;
 			return -1;
 #endif
 		}
+		root->just_mapped = 1;
 	}
 	else { /* matching real_path: reuse */
 		TODO("TODO#41: sharing root pointers may not be a good idea: they will not have unique names; see the other TODO#41");
-		free(path); /* we are going to use the existing one in root */
+		free(path); path = NULL;/* we are going to use the existing one in root */
 		if (root->backend != be_new) {
 			if (real_path != path) free(real_path);
 			if (optional)
 				return 0;
-			rnd_message(RND_MSG_ERROR, "Symbol library mapping error: different plugins claim to handle '%s'\n", path);
+			rnd_message(RND_MSG_ERROR, "Symbol library mapping error: different plugins claim to handle '%s'\n", root->name);
 			return -1;
 		}
+		if (do_rehash) {
+			if (csch_lib_rehash(sheet, master, root) != 0) {
+				rnd_message(RND_MSG_ERROR, "Symbol library mapping error: failed to re-scan library '%s'\n", root->name);
+				root->just_mapped = 1;
+			}
+			else
+				append = 0; /* do not add orig_root, rehash has replaced it */
+		}
 	}
 
 	if (sheet->libs.used <= master->uid)
@@ -325,7 +341,7 @@ int csch_lib_rehash(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *
 		rnd_message(RND_MSG_ERROR, "csch_lib_rehash(): failed to find original root\n");
 		return -1;
 	}
-	if (csch_lib_add(sheet, master, rnd_strdup(root->name), 0) != 0) {
+	if (csch_lib_add(sheet, master, rnd_strdup(root->name), 0, 1, 0) != 0) {
 		rnd_message(RND_MSG_ERROR, "csch_lib_rehash(): failed to rehash %s\nDid it disappear meanwhile?\n", root->realpath);
 		htsp_set(&master->roots, root->realpath, orig_root);
 		return -1;
@@ -347,12 +363,26 @@ int csch_lib_rehash(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *
 	return 0;
 }
 
-void csch_lib_add_all(csch_sheet_t *sheet, csch_lib_master_t *master, const rnd_conflist_t *searchpath)
+void csch_lib_add_all(csch_sheet_t *sheet, csch_lib_master_t *master, const rnd_conflist_t *searchpath, int do_rehash)
 {
 	rnd_conf_listitem_t *ci;
+
+	/* clear the just_mapped bit so that csch_lib_add() can set it */
 	for(ci = rnd_conflist_first((rnd_conflist_t *)searchpath); ci != NULL; ci = rnd_conflist_next(ci)) {
 		const char *p = ci->val.string[0];
-		csch_lib_add(sheet, master, rnd_strdup(p), 1);
+		const csch_lib_backend_t *be_new;
+		char *real_path = slib_find_realpath(&sheet->hidlib, master, p, &be_new);
+		if (real_path != NULL) {
+			csch_lib_t *root = htsp_get(&master->roots, real_path);
+			if (root != NULL)
+				root->just_mapped = 0;
+		}
+	}
+
+	/* (re)load each, but make sure everything is scanned only once */
+	for(ci = rnd_conflist_first((rnd_conflist_t *)searchpath); ci != NULL; ci = rnd_conflist_next(ci)) {
+		const char *p = ci->val.string[0];
+		csch_lib_add(sheet, master, rnd_strdup(p), 1, do_rehash, 1);
 	}
 }
 
