@@ -29,6 +29,7 @@
 #include "config.h"
 
 #include <librnd/core/error.h>
+#include <librnd/core/misc_util.h>
 
 #include "abstract.h"
 #include "compile.h"
@@ -79,6 +80,9 @@ csch_anet_t *csch_cmp_merge_nets(csch_anet_t *n1, csch_anet_t *n2)
 	}
 	src->conns.used = 0;
 
+	/* copy/merge all attributes */
+	csch_attrib_copy_all_undoable(NULL, NULL, &dst->hdr.attr, &src->hdr.attr, 0);
+
 	/* copy all sources from src to dst */
 	for(n = 0; n < src->hdr.srcs.used; n++)
 		csch_compile_add_source(src->hdr.srcs.array[n], &dst->hdr);
@@ -116,7 +120,7 @@ int csch_cmp_nameconn_port_net(csch_acomp_t *comp, const char *portname, const c
 		return -1;
 	}
 	if (port->conn.net == NULL) {
-TODO("TODO#rgc: we shouldn't have require conn parameter, this should be checked in drc");
+TODO("TODO#rgc: drc/require_graphical_conn should be checked in drc");
 /* TODO: cases to check:
    - place resistor, add conn array 4:foo; this should connect a 4th port of
      the resistor to network foo, with no error; csch_compile_connect_net_to()
@@ -127,8 +131,13 @@ TODO("TODO#rgc: we shouldn't have require conn parameter, this should be checked
 */
 		csch_compile_connect_net_to(&net, &port->hdr, 1);
 		if (require_conn) {
-			rnd_message(RND_MSG_ERROR, "Port '%s-%s' has a non-graphical connection to net %s, but no graphical connection\n", comp->name, portname, netname);
-			return -1;
+			csch_attrib_t *a = csch_attrib_get(&port->hdr.attr, "drc/require_graphical_conn");
+			if ((a != NULL) && rnd_istrue(a->val)) {
+				rnd_message(RND_MSG_ERROR, "Port '%s-%s' has a non-graphical connection to net %s, but no graphical connection\n", comp->name, portname, netname);
+				return -1;
+			}
+			else
+				return 0;
 		}
 		return 0;
 	}
