@@ -90,7 +90,7 @@ static csch_rtree_dir_t find_wire_cb(void *ctx_, void *obj_, const csch_rtree_bo
 }
 
 
-csch_line_t *find_wire(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y, csch_chdr_t *ignore)
+static csch_line_t *find_wire(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y, csch_chdr_t *ignore)
 {
 	find_wire_t ctx = {0};
 	csch_rtree_box_t query;
@@ -187,13 +187,16 @@ static csch_rtree_dir_t wire_merge_cb(void *ctx_, void *obj_, const csch_rtree_b
 	if (dir != ctx->dir)
 		return csch_RTREE_DIR_NOT_FOUND_CONT;
 
+	/* merge only if they intersect - close parallel diagonals have
+	   overlapping bbox without actual intersection shall not be merged */
+	if (csch_obj_intersect_obj(line->hdr.sheet, &line->hdr, &ctx->self->hdr, NULL, 0) < 1)
+		return csch_RTREE_DIR_NOT_FOUND_CONT;
+
 	vtp0_append(&ctx->lines, line);
 	return csch_RTREE_DIR_FOUND_CONT;
 }
 
-/* merges any lines that connect with "line" from within the same wirenet and
-   has the same direction; line is never removed */
-RND_INLINE void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line)
+void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line, int remove_overlap)
 {
 	wire_merge_t ctx = {0};
 	g2d_vect_t min, max;
@@ -225,6 +228,70 @@ RND_INLINE void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line
 
 		for(n = 0; n < ctx.lines.used; n++) {
 			csch_line_t *l = ctx.lines.array[n];
+
+			if (remove_overlap) {
+				int full_overlap = (g2d_dist2_cline_pt(&l->inst.c, line->inst.c.p1) <= 4) && (g2d_dist2_cline_pt(&l->inst.c, line->inst.c.p1) <= 4);
+				if (full_overlap) {
+					int trunc = 0, full = 0;
+
+					/* figure which end(s) of the shorter "line" is on the
+					   longer "l" just found. Set trunc=1 only if at least one endpoint of
+					   the two lines match */
+					x1 = l->inst.c.p1.x; y1 = l->inst.c.p1.y;
+					x2 = l->inst.c.p2.x; y2 = l->inst.c.p2.y;
+					if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p1, line->inst.c.p1)) {
+						x1 = line->inst.c.p2.x; y1 = line->inst.c.p2.y;
+						trunc = 1;
+						if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p2, line->inst.c.p2))
+							full = 1;
+					}
+					else if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p1, line->inst.c.p2)) {
+						x1 = line->inst.c.p1.x; y1 = line->inst.c.p1.y;
+						trunc = 1;
+						if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p2, line->inst.c.p1))
+							full = 1;
+					}
+					if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p2, line->inst.c.p1)) {
+						x2 = line->inst.c.p2.x; y2 = line->inst.c.p2.y;
+						trunc = 1;
+						if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p1, line->inst.c.p2))
+							full = 1;
+					}
+					else if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p2, line->inst.c.p2)) {
+						x2 = line->inst.c.p1.x; y2 = line->inst.c.p1.y;
+						trunc = 1;
+						if (g2d_vect_t_eq_g2d_vect_t(l->inst.c.p2, line->inst.c.p1))
+							full = 1;
+					}
+
+					/* if we got here with trunc == 0, the shorter line is in
+					   the middle of the longer line and we shouldn't truncate for
+					   this overlap. (This is when no endpoint-endpoint match is found) */
+					if (trunc) {
+						ctx.wirenet->wirenet_recalc_lock = 1;
+						ctx.wirenet->wirenet_split_lock = 1;
+
+						if (!full) {
+							/* truncate l, removing the segment overlapping with "line" */
+							csch_cgrp_vinverse_xform(ctx.wirenet, &x1, &y1, &x2, &y2, NULL);
+							csch_line_modify(sheet, l, &x1, &y1, &x2, &y2, 1, 0, 0);
+						}
+						else {
+							/* upon full overlap, remove l */
+							csch_op_remove(sheet, &l->hdr);
+						}
+
+						/* remove the new "line", it's in overlap */
+						csch_op_remove(sheet, &line->hdr);
+
+						ctx.wirenet->wirenet_recalc_lock = 0;
+						ctx.wirenet->wirenet_split_lock = 0;
+						csch_wirenet_recalc_junctions(sheet, ctx.wirenet);
+						goto quit;
+					}
+				}
+			}
+
 /*			rnd_trace(" #%d\n", l->hdr.oid);*/
 			if (ctx.dir == 1000) { /* horizontal, use x */
 				if (l->inst.c.p1.x < min.x)
@@ -248,14 +315,14 @@ RND_INLINE void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line
 			}
 		}
 
-		ctx.wirenet->wirenet_recalc_lock = 1;
-		ctx.wirenet->wirenet_split_lock = 1;
-
 		/* extend the new line; inverse-transform edit coords so they are in the
 		   wirenet's coord system */
 		x1 = min.x; y1 = min.y;
 		x2 = max.x; y2 = max.y;
 
+		ctx.wirenet->wirenet_recalc_lock = 1;
+		ctx.wirenet->wirenet_split_lock = 1;
+
 		csch_cgrp_vinverse_xform(ctx.wirenet, &x1, &y1, &x2, &y2, NULL);
 		csch_line_modify(sheet, line, &x1, &y1, &x2, &y2, 1, 0, 0);
 
@@ -272,7 +339,7 @@ RND_INLINE void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line
 /*		rnd_trace("final: %d;%d  %d;%d\n", min.x, min.y, max.x, max.y);*/
 	}
 
-
+	quit:;
 	vtp0_uninit(&ctx.lines);
 }
 
@@ -444,7 +511,7 @@ static void csch_wirenet_invalidate_dyntext(csch_sheet_t *sheet, csch_cgrp_t *gr
 }
 
 /* check every line of an already placed group to see if any wirenet-wirenet
-   connection is made and merge if so */
+   connection is made and merge the groups if so */
 static void csch_wirenet_recalc_merges(csch_sheet_t *sheet, csch_cgrp_t *grp)
 {
 	htip_entry_t *e;
@@ -470,6 +537,7 @@ static void csch_wirenet_recalc_merges(csch_sheet_t *sheet, csch_cgrp_t *grp)
 		const char *old_name = csch_attrib_get_str(&grp->attr, "name");
 		const char *new_name = NULL, *final_name = old_name;
 		int num_names = (old_name == NULL) ? 0 : 1;
+		vtp0_t newos = {0};
 
 		/* figure number of names and new name, if needed */
 		for(n = 0; n < adj_grp.used; n++) {
@@ -489,13 +557,23 @@ static void csch_wirenet_recalc_merges(csch_sheet_t *sheet, csch_cgrp_t *grp)
 			csch_cgrp_t *agrp = adj_grp.array[n];
 			rnd_trace("  #%ld\n", agrp->hdr.oid);
 			agrp->role = 0;
-			csch_op_merge_into(sheet, grp, agrp);
+			csch_op_merge_into_remember(sheet, grp, agrp, &newos);
 			agrp->role = CSCH_ROLE_WIRE_NET;
 			if (agrp->hdr.parent != NULL)
 				csch_op_remove(sheet, &agrp->hdr);
 		}
 		grp->role = CSCH_ROLE_WIRE_NET;
 
+		/* revisit each object merged from adj grp, there may be overlapping lines,
+		   those didn't get merged because we disabled side effects */
+		for(n = 0; n < newos.used; n++) {
+			csch_chdr_t *line = newos.array[n];
+			if (line->type == CSCH_CTYPE_LINE)
+				csch_wirenet_recalc_merge(sheet, (csch_line_t *)line, 0);
+		}
+		vtp0_uninit(&newos);
+
+
 		if (new_name != NULL) {
 			csch_source_arg_t *src = csch_attrib_src_c(NULL, 0, 0, "graphical network merge");
 			csch_attrib_set(&grp->attr, 0, "name", new_name, src, NULL);
@@ -547,6 +625,25 @@ static csch_line_t *csch_wirenet_find_existing(csch_sheet_t *sheet, csch_coord_t
 	return ctx.res;
 }
 
+csch_line_t *csch_wirenet_draw_line_in(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_comm_str_t stroke_name, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2)
+{
+	csch_line_t *line;
+
+	/* transform the coords of the new line to undo the parent group's
+	   transformations */
+	csch_cgrp_vinverse_xform(parent, &x1, &y1, NULL);
+	csch_cgrp_vinverse_xform(parent, &x2, &y2, NULL);
+
+	line = (csch_line_t *)csch_op_create(sheet, parent, CSCH_CTYPE_LINE);
+	line->spec.p1.x = x1; line->spec.p1.y = y1;
+	line->spec.p2.x = x2; line->spec.p2.y = y2;
+	line->hdr.stroke_name = stroke_name;
+	csch_line_update(sheet, line, 1);
+	csch_cgrp_bbox_update(sheet, parent);
+
+	return line;
+}
+
 csch_chdr_t *csch_wirenet_draw(csch_sheet_t *sheet, csch_comm_str_t stroke_name, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2)
 {
 	csch_line_t *line;
@@ -577,17 +674,7 @@ csch_chdr_t *csch_wirenet_draw(csch_sheet_t *sheet, csch_comm_str_t stroke_name,
 	if (parent == NULL)
 		return NULL;
 
-	/* transform the coords of the new line to undo the parent group's
-	   transformations */
-		csch_cgrp_vinverse_xform(parent, &x1, &y1, NULL);
-		csch_cgrp_vinverse_xform(parent, &x2, &y2, NULL);
-
-	line = (csch_line_t *)csch_op_create(sheet, parent, CSCH_CTYPE_LINE);
-	line->spec.p1.x = x1; line->spec.p1.y = y1;
-	line->spec.p2.x = x2; line->spec.p2.y = y2;
-	line->hdr.stroke_name = stroke_name;
-	csch_line_update(sheet, line, 1);
-	csch_cgrp_bbox_update(sheet, parent);
+	line = csch_wirenet_draw_line_in(sheet, parent, stroke_name, x1, y1, x2, y2);
 
 	if (merge_res > 0) {
 		int lock_save = parent->wirenet_split_lock;
@@ -603,7 +690,7 @@ csch_chdr_t *csch_wirenet_draw(csch_sheet_t *sheet, csch_comm_str_t stroke_name,
 	}
 
 	csch_wirenet_recalc_obj_conn(sheet, &line->hdr);
-	csch_wirenet_recalc_merge(sheet, line); /* must be the last */
+	csch_wirenet_recalc_merge(sheet, line, 0); /* must be the last */
 
 	uundo_unfreeze_serial(&sheet->undo);
 	uundo_inc_serial(&sheet->undo);
@@ -1017,6 +1104,15 @@ void csch_wirenet_recalc_line_chg(csch_sheet_t *sheet, csch_line_t *line)
 
 	csch_wirenet_newseg2wirenets(sheet, &map, line, &new_wirenets);
 
+	/* Install conns at new coords before net merge; order matters, because if
+	   the wirenet of the edited line gets merged into another, existing wirenet,
+	   that will inherit the connections we find here; but if connections
+	   are calculated only after the merge in csch_wirenet_newline_merge_parent(),
+	   then "line" is already a deleted object from the old, now deleted wirenet
+	   and the connection is not made on deleted objects.
+	   Test case: tests/manual/cn1 */
+	csch_wirenet_recalc_obj_conn(sheet, &line->hdr);
+
 	/* check if the endpoints of the line now connects other wirenets and merge them */
 	{
 		csch_cgrp_t *parent;
@@ -1039,7 +1135,6 @@ void csch_wirenet_recalc_line_chg(csch_sheet_t *sheet, csch_line_t *line)
 
 	map_uninit(&map);
 
-	csch_wirenet_recalc_obj_conn(sheet, &line->hdr);
 }
 
 
