@@ -51,6 +51,18 @@ int csch_wire_count_junctions(csch_chdr_t *wno, int *mid_cnt_out);
    other line won't have its endpoint in the middle of the new line */
 int csch_is_wireline_safe(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2);
 
+/*** low level ***/
+
+/* Create a new wire line within a wirenet without updating or recalculating
+   the wirenet */
+csch_line_t *csch_wirenet_draw_line_in(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_comm_str_t stroke_name, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2);
+
+/* merges any lines that connect with "line" from within the same wirenet and
+   has the same direction; if remove_overlap is 0, line is never removed;
+   if remove_overlap is 1, if line fully overlaps with an existing wire from
+   one end of that wire, the wire is truncated (and line is removed) */
+void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line, int remove_overlap);
+
 
 /*** implementation ***/
 RND_INLINE int csch_obj_is_junction(csch_chdr_t *obj)
