@@ -35,6 +35,7 @@
 #include <libcschem/concrete.h>
 #include <libcschem/project.h>
 #include <libcschem/cnc_conn.h>
+#include <libcschem/intersect.h>
 #include <libcschem/util_abst.h>
 #include <libcschem/util_wirenet.h>
 
@@ -46,38 +47,43 @@
 /*** generic/helper ***/
 
 /* Figure if an attribute modification entry can be autofixed */
-static sch_rnd_backann_auto_t *auto_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, csch_attribs_t *attrs, const char *key, const char *want)
+static sch_rnd_backann_auto_t *auto_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, csch_attribs_t *attrs, const char *key, const char *want, csch_ahdr_t *fallback_aobj)
 {
 	csch_attrib_t *attr = csch_attrib_get(attrs, key);
 	sch_rnd_backann_auto_t *res;
 	long n;
-	int prio, found = 0;
+	int prio, found = 0, is_str;
 	csch_chdr_t *cobj;
 	csch_ahdr_t *aobj;
 	const char *desc;
 
-	if (attr == NULL)
-		return NULL;
+	if ((attr != NULL) && (attr->source.used >= 1)) {
+		/* pick the first actual write going back from the end, ignore failed writes */
+		for(n = attr->source.used-1; n >= 0; n--) {
+			int pr;
+			csch_attrib_src_type_t type;
+			char *source = attr->source.array[n];
 
-	if (attr->source.used < 1)
-		return NULL;
+			pr = csch_attrib_src_parse(ctx->sheet, source, &prio, &type, &cobj, &aobj, NULL, &desc);
+			if ((pr != 0) || (type & CSCH_ASRCT_FAIL))
+				continue;
 
-	/* pick the first actual write going back from the end, ignore failed writes */
-	for(n = attr->source.used-1; n >= 0; n--) {
-		int pr;
-		csch_attrib_src_type_t type;
-		char *source = attr->source.array[n];
+			found = 1;
+			break;
+		}
 
-		pr = csch_attrib_src_parse(ctx->sheet, source, &prio, &type, &cobj, &aobj, NULL, &desc);
-		if ((pr != 0) || (type & CSCH_ASRCT_FAIL))
-			continue;
+		if (!found)
+			return NULL;
 
-		found = 1;
-		break;
+		is_str = (attr->val != NULL);
+	}
+	else { /* setting an attribute that doesn't exist -> set it on the first source object */
+		aobj = fallback_aobj;
+		if (aobj->srcs.used < 1)
+			return NULL; /* no source object available */
+		cobj = aobj->srcs.array[0];
+		is_str = 1;
 	}
-
-	if (!found)
-		return NULL;
 
 	assert(csch_obj_is_grp(cobj));
 
@@ -85,8 +91,8 @@ static sch_rnd_backann_auto_t *auto_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *b
 	res->attr.type = SCH_RND_BAA_ATTR;
 	res->attr.grp = (csch_cgrp_t *)cobj;
 	res->attr.key = rnd_strdup(key);
-	res->attr.want_val = rnd_strdup(want);
-	res->attr.is_str = (attr->val != NULL);
+	res->attr.want_val = (want == NULL) ? NULL : rnd_strdup(want);
+	res->attr.is_str = is_str;
 
 	return res;
 }
@@ -186,7 +192,7 @@ double find_straight_line_between(csch_cgrp_t *term, csch_cgrp_t *wn, csch_chdr_
    in the connection from the terminal's or the wirenet's side, respectively.
    If newline is not NULL and there's no connection, find a terminal and a
    wirenet on the same sheet and figure a straight line that'd connect them */
-int get_term_net_gr_conn(csch_project_t *prj, const char *netname, const char *compname, const char *termname, csch_chdr_t **termo_out, csch_chdr_t **wno_out, csch_conn_t **conn_out, csch_coord_t *newline)
+static int get_term_net_gr_conn(csch_project_t *prj, const char *netname, const char *compname, const char *termname, csch_chdr_t **termo_out, csch_chdr_t **wno_out, csch_conn_t **conn_out, csch_coord_t *newline)
 {
 	csch_anet_t *net;
 	csch_acomp_t *comp;
@@ -194,6 +200,7 @@ int get_term_net_gr_conn(csch_project_t *prj, const char *netname, const char *c
 	long tn, cn;
 	vtp0_t conns = {0};
 	int resi = -1;
+	csch_chdr_t *found_wire = NULL, *found_term = NULL;
 
 	if (termo_out != NULL) *termo_out = NULL;
 	if (wno_out != NULL) *wno_out = NULL;
@@ -237,13 +244,18 @@ int get_term_net_gr_conn(csch_project_t *prj, const char *netname, const char *c
 		for(on = 0; on < conn->conn.used; on++) {
 			csch_chdr_t *obj = conn->conn.array[on];
 			if ((obj->parent->role == CSCH_ROLE_TERMINAL) && (csch_cgrp_is_in_asrc(obj->parent, &port->hdr)))
-				termo = obj;
+				found_term = termo = obj;
 			else if ((obj->parent->role == CSCH_ROLE_WIRE_NET) && (csch_cgrp_is_in_asrc(obj->parent, &net->hdr))) {
 				rnd_trace("  found wn obj %p\n", obj);
 				resi = 0;
-				if (termo_out != NULL) *termo_out = termo;
-				if (wno_out != NULL) *wno_out = obj;
+				found_wire = obj;
 				if (conn_out != NULL) *conn_out = conn;
+			}
+
+			/* we are done if we have both a wire and a terminal object */
+			if ((found_wire != NULL) && (found_term != NULL)) {
+				if (termo_out != NULL) *termo_out = found_term;
+				if (wno_out != NULL) *wno_out = found_wire;
 				goto done;
 			}
 		}
@@ -280,23 +292,91 @@ int get_term_net_gr_conn(csch_project_t *prj, const char *netname, const char *c
 	return resi;
 }
 
-/*** insrtuctions ***/
+
+void calc_break_grconn_fixable(sch_rnd_backann_auto_t *res)
+{
+	csch_chdr_t *wireo = res->break_grconn.wire_obj;
+	csch_chdr_t *termo = res->break_grconn.term_obj;
+	csch_line_t *wirel = (csch_line_t *)wireo;
+	csch_sheet_t *sheet = wireo->sheet;
+	g2d_vect_t iscp[2];
+	long len;
+	double wlen, dx, dy;
+
+	/* assume we can't fix this by default */
+	res->break_grconn.endp = 0;
+
+	/* can tune endpoint of line wires only */
+	if (wireo->type != CSCH_CTYPE_LINE)
+		return;
+
+	/* if there is not exactly one intersections it's a complicated case */
+	len = csch_obj_intersect_obj(sheet, wireo, termo, iscp, 2);
+	if (len != 1)
+		return;
+
+	dx = wirel->inst.c.p1.x - wirel->inst.c.p2.x;
+	dy = wirel->inst.c.p1.y - wirel->inst.c.p2.y;
+	wlen = sqrt(dx*dx + dy*dy);
+
+	/* wire too short for safe endpoint modification */
+	if (wlen < 2000)
+		return;
+
+	/* iscp[0] has the wire point that should be moved away - if it's an
+	   endpoint of that wire; else it's a T junction and we are not going to
+	   fix that */
+	if ((wirel->inst.c.p1.x == iscp[0].x) && (wirel->inst.c.p1.y == iscp[0].y)) {
+		res->break_grconn.endp = 1;
+		res->break_grconn.newx = wirel->inst.c.p1.x - dx / wlen * 1000;
+		res->break_grconn.newy = wirel->inst.c.p1.y - dy / wlen * 1000;
+/*		rnd_trace("endp1 to %ld %ld\n", res->break_grconn.newx, res->break_grconn.newy);*/
+	}
+	else if ((wirel->inst.c.p2.x == iscp[0].x) && (wirel->inst.c.p2.y == iscp[0].y)) {
+		res->break_grconn.endp = 2;
+		res->break_grconn.newx = wirel->inst.c.p2.x + dx / wlen * 1000;
+		res->break_grconn.newy = wirel->inst.c.p2.y + dy / wlen * 1000;
+/*		rnd_trace("endp2 to %ld %ld\n", res->break_grconn.newx, res->break_grconn.newy);*/
+	}
+}
+
+/*** instructions ***/
 static sch_rnd_backann_auto_t *auto_conn_del(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
 {
 	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;
 	csch_chdr_t *termo, *wno;
+	csch_anet_t *net;
 	csch_conn_t *conn;
 	sch_rnd_backann_auto_t *res;
-	int jnc, jnc_mid;
+	int jnc_mid;
 	int tricky = 0;
 
+
+
 	if (get_term_net_gr_conn(prj, ba->value.conn_del.net, ba->value.conn_del.comp, ba->value.conn_del.term, &termo, &wno, &conn, NULL) != 0)
 		return NULL;
 
-	jnc = csch_wire_count_junctions(wno, &jnc_mid);
+	net = csch_anet_get(prj->abst, ba->value.conn_del.net, 0, 0);
+	if (net == NULL)
+		return NULL;
+
+	if (net->conns.used == 1) {
+		/* by now we are sure our terminal is connected to the net so this one
+		   connection must be the same as net's conn list's. In this case
+		   remove the whole wirenet (removal of the last connection means
+		   removal of the wirenet). */
+		res = calloc(sizeof(sch_rnd_backann_auto_t), 1);
+		res->del.type = SCH_RND_BAA_DEL;
+		res->del.obj = &wno->parent->hdr;
+		return res;
+	}
+
+
+	csch_wire_count_junctions(wno, &jnc_mid);
 
 	/* t1---+---t2; if removed for t1, the section between the mid junction and t2 is also broken */
-	tricky |= (wno->conn.used > 1) && (jnc > 0);
+	/* t1-------t2; if removed for t1, the connection to t2 is also broken */
+	tricky |= (wno->conn.used > 1);
 
 	/* t1---+---+; if removed for t1, the section between the mid junction and endpoint is also broken */
 	tricky |= (jnc_mid > 0);
@@ -306,9 +386,10 @@ static sch_rnd_backann_auto_t *auto_conn_del(sch_rnd_backann_t *ctx, sch_rnd_ba_
 		res->break_grconn.type = SCH_RND_BAA_BREAK_GRCONN;
 		res->break_grconn.wire_obj = wno;
 		res->break_grconn.term_obj = termo;
+		calc_break_grconn_fixable(res);
 	}
 	else {
-		res = malloc(sizeof(sch_rnd_backann_auto_t));
+		res = calloc(sizeof(sch_rnd_backann_auto_t), 1);
 		res->del.type = SCH_RND_BAA_DEL;
 		res->del.obj = wno;
 	}
@@ -348,7 +429,7 @@ static sch_rnd_backann_auto_t *auto_net_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_
 	if (net == NULL)
 		return NULL;
 
-	return auto_attr(ctx, ba, &net->hdr.attr, ba->value.net_attr.key, ba->value.net_attr.val);
+	return auto_attr(ctx, ba, &net->hdr.attr, ba->value.net_attr.key, ba->value.net_attr.val, &net->hdr);
 }
 
 static sch_rnd_backann_auto_t *auto_comp_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
@@ -360,7 +441,7 @@ static sch_rnd_backann_auto_t *auto_comp_attr(sch_rnd_backann_t *ctx, sch_rnd_ba
 	if (comp == NULL)
 		return NULL;
 
-	return auto_attr(ctx, ba, &comp->hdr.attr, ba->value.comp_attr.key, ba->value.comp_attr.val);
+	return auto_attr(ctx, ba, &comp->hdr.attr, ba->value.comp_attr.key, ba->value.comp_attr.val, &comp->hdr);
 }
 
 static sch_rnd_backann_auto_t *auto_term_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
@@ -377,7 +458,43 @@ static sch_rnd_backann_auto_t *auto_term_attr(sch_rnd_backann_t *ctx, sch_rnd_ba
 	if (port == NULL)
 		return NULL;
 
-	return auto_attr(ctx, ba, &port->hdr.attr, ba->value.term_attr.key, ba->value.term_attr.val);
+	return auto_attr(ctx, ba, &port->hdr.attr, ba->value.term_attr.key, ba->value.term_attr.val, &port->hdr);
+}
+
+static sch_rnd_backann_auto_t *auto_comp_add(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
+{
+/*	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;*/
+	sch_rnd_backann_auto_t *res;
+
+	res = malloc(sizeof(sch_rnd_backann_auto_t));
+	res->log.type = SCH_RND_BAA_LOG;
+	res->log.str = rnd_strdup_printf("Use the {w l} library window to place a symbol\nthen {a a} to change its name to %s\n", ba->value.comp_add.comp);
+
+	return res;
+}
+
+static sch_rnd_backann_auto_t *auto_comp_del(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
+{
+	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;
+	csch_acomp_t *comp;
+	sch_rnd_backann_auto_t *res;
+
+	comp = csch_acomp_get(prj->abst, ba->value.comp_del.comp, 0);
+	if ((comp == NULL) || (comp->hdr.srcs.used < 1))
+		return NULL;
+
+	res = calloc(sizeof(sch_rnd_backann_auto_t), 1);
+	res->del.type = SCH_RND_BAA_DEL;
+	if (comp->hdr.srcs.used > 1) {
+		long n;
+		vtp0_enlarge(&res->del.objlist, comp->hdr.srcs.used-1);
+		for(n = 0; n < comp->hdr.srcs.used; n++)
+			res->del.objlist.array[n] = comp->hdr.srcs.array[n];
+	}
+	else
+		res->del.obj = comp->hdr.srcs.array[0]; /* save an extra allocation for a common case when there's only one object */
+
+	return res;
 }
 
 /*** API ***/
@@ -391,6 +508,8 @@ sch_rnd_backann_auto_t *sch_rnd_backann_auto_entry(sch_rnd_backann_t *ctx, sch_r
 		case SCH_RND_BAT_NET_ATTR:    return auto_net_attr(ctx, ba);
 		case SCH_RND_BAT_COMP_ATTR:   return auto_comp_attr(ctx, ba);
 		case SCH_RND_BAT_TERM_ATTR:   return auto_term_attr(ctx, ba);
+		case SCH_RND_BAT_COMP_DEL:    return auto_comp_del(ctx, ba);
+		case SCH_RND_BAT_COMP_ADD:    return auto_comp_add(ctx, ba);
 		case SCH_RND_BAT_invalid:     break;
 	}
 	return NULL;
@@ -405,8 +524,15 @@ void sch_rnd_backann_auto_free(sch_rnd_backann_auto_t *au)
 			free(au->attr.want_val);
 			break;
 
-		/* no dynamic allocated fields */
+		case SCH_RND_BAA_LOG:
+			free(au->log.str);
+			break;
+
 		case SCH_RND_BAA_DEL:
+			vtp0_uninit(&au->del.objlist);
+			break;
+
+		/* no dynamic allocated fields */
 		case SCH_RND_BAA_BREAK_GRCONN:
 		case SCH_RND_BAA_MAKE_GRCONN:
 			break;
