@@ -51,7 +51,7 @@ static const char sch_backann_cookie[] = "backann plugin";
 #include "auto_ba.h"
 
 #include "dlg_ba.c"
-#include "parse_bap.c"
+#include "parse_backann.c"
 
 htpp_t sch_rnd_prj2backann;
 int sch_rnd_prj2backann_inited;
