@@ -129,6 +129,27 @@ static int check_conn_add(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, long *pend)
 	return 0;
 }
 
+static int check_comp_del(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, long *pend)
+{
+	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;
+	csch_acomp_t *acomp = csch_acomp_get(prj->abst, ba->value.comp_del.comp, 0);
+
+	ba->status = (acomp == NULL) ? SCH_RND_BAS_DONE : SCH_RND_BAS_PENDING;
+
+	return 0;
+}
+
+static int check_comp_add(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, long *pend)
+{
+	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;
+	csch_acomp_t *acomp = csch_acomp_get(prj->abst, ba->value.comp_del.comp, 0);
+
+	ba->status = (acomp != NULL) ? SCH_RND_BAS_DONE : SCH_RND_BAS_PENDING;
+
+	return 0;
+}
+
+
 static int check_net_attr(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, long *pend)
 {
 	csch_project_t *prj = (csch_project_t *)ctx->sheet->hidlib.project;
@@ -180,6 +201,8 @@ int sch_rnd_backann_check_entry(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba, long *
 		case SCH_RND_BAT_NET_ATTR:    return check_net_attr(ctx, ba, pend);
 		case SCH_RND_BAT_COMP_ATTR:   return check_comp_attr(ctx, ba, pend);
 		case SCH_RND_BAT_TERM_ATTR:   return check_term_attr(ctx, ba, pend);
+		case SCH_RND_BAT_COMP_DEL:    return check_comp_del(ctx, ba, pend);
+		case SCH_RND_BAT_COMP_ADD:    return check_comp_add(ctx, ba, pend);
 		case SCH_RND_BAT_invalid:     break;
 	}
 	return -1;
