@@ -31,6 +31,7 @@
 
 #include <librnd/hid/hid_dad_tree.h>
 
+#include <libcschem/actions_csch.h>
 #include <libcschem/attrib.h>
 #include <libcschem/project.h>
 #include <libcschem/operation.h>
@@ -69,7 +70,11 @@ static char *backann_sprint_entry(sch_rnd_ba_t *ba)
 		case SCH_RND_BAT_COMP_ATTR:
 			return rnd_strdup_printf("set attr: component %s and %s=%s", ba->value.comp_attr.comp, ba->value.comp_attr.key, ba->value.comp_attr.val);
 		case SCH_RND_BAT_TERM_ATTR:
-			return rnd_strdup_printf("set attr: term %s and %s=%s", ba->value.term_attr.term, ba->value.term_attr.key, ba->value.term_attr.val);
+			return rnd_strdup_printf("set attr: comp %s term %s and %s=%s", ba->value.term_attr.comp, ba->value.term_attr.term, ba->value.term_attr.key, ba->value.term_attr.val);
+		case SCH_RND_BAT_COMP_DEL:
+			return rnd_strdup_printf("delete comp %s", ba->value.comp_del.comp);
+		case SCH_RND_BAT_COMP_ADD:
+			return rnd_strdup_printf("create comp %s", ba->value.comp_add.comp);
 		case SCH_RND_BAT_invalid: break;
 	}
 	return rnd_strdup_printf("Invalid entry (%ld)", ba->type);
@@ -156,10 +161,19 @@ static int sch_rnd_backann_ensure_abst(sch_rnd_backann_t *ctx)
 	} \
 	au = sch_rnd_backann_auto_entry(ctx, ba); \
 	if (au == NULL) { \
-		rnd_message(RND_MSG_ERROR, "Can not figure this entry #1\n"); \
+		rnd_message(RND_MSG_ERROR, "Can not figure this entry (backann_auto_entry failed)\n"); \
 		return; \
 	}
 
+static void append_print_obj(gds_t *dst, csch_chdr_t *obj)
+{
+	csch_oidpath_t oidp = {0};
+
+	gds_append_str(dst, "object:");
+	csch_oidpath_from_obj(&oidp, obj);
+	csch_oidpath_to_str_append(dst, &oidp);
+	csch_oidpath_free(&oidp);
+}
 
 static void details_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr_btn)
 {
@@ -168,7 +182,7 @@ static void details_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 
 	switch(au->any.type) {
 		case SCH_RND_BAA_ATTR:
-			{
+			if (au->attr.grp != NULL) {
 				gds_t tmp = {0};
 				csch_oidpath_t oidp = {0};
 				fgw_arg_t args[4], ares;
@@ -186,29 +200,41 @@ static void details_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 				
 				/* tmp is free'd because it's been passed with FGW_DYN */
 			}
+			else
+				rnd_message(RND_MSG_ERROR, "Can not find the object whose attributes are to be edited\n");
 			break;
 
 		case SCH_RND_BAA_DEL:
-			{
-				gds_t tmp = {0};
-				csch_oidpath_t oidp = {0};
-				fgw_arg_t args[4], ares;
-				csch_sheet_t *sheet = au->del.obj->sheet;
+			if ((au->del.obj != NULL) || (au->del.objlist.used > 0)) {
+				if (au->del.obj != NULL) {
+					gds_t tmp = {0};
+					fgw_arg_t args[4], ares;
+					csch_sheet_t *sheet = au->del.obj->sheet;
 
-				gds_append_str(&tmp, "object:");
-				csch_oidpath_from_obj(&oidp, au->del.obj);
-				csch_oidpath_to_str_append(&tmp, &oidp);
-				csch_oidpath_free(&oidp);
+					append_print_obj(&tmp, au->del.obj);
 
-				args[1].type = FGW_STR | FGW_DYN; args[1].val.str = tmp.array;
-				rnd_actionv_bin(&sheet->hidlib, "TreeDialog", &ares, 2, args);
-				fgw_arg_free(&rnd_fgw, &ares);
-				/* tmp is free'd because it's been passed with FGW_DYN */
+					args[1].type = FGW_STR | FGW_DYN; args[1].val.str = tmp.array;
+					rnd_actionv_bin(&sheet->hidlib, "TreeDialog", &ares, 2, args);
+					fgw_arg_free(&rnd_fgw, &ares);
+					/* tmp is free'd because it's been passed with FGW_DYN */
+				}
+				if (au->del.objlist.used > 0) {
+					fgw_arg_t args[4], ares;
+					csch_chdr_t *obj = au->del.objlist.array[0];
+					csch_sheet_t *sheet = obj->sheet;
+
+					args[1].type = FGW_STR; args[1].val.str = "objarr";
+					fgw_ptr_reg(&rnd_fgw, &args[2], CSCH_PTR_DOMAIN_COBJ_ARR, FGW_PTR | FGW_STRUCT, &au->del.objlist);
+					rnd_actionv_bin(&sheet->hidlib, "TreeDialog", &ares, 3, args);
+					fgw_ptr_unreg(&rnd_fgw, &args[2], CSCH_PTR_DOMAIN_COBJ_ARR);
+				}
 			}
+			else
+				rnd_message(RND_MSG_ERROR, "Can not find the object to delete\n");
 			break;
 
 		case SCH_RND_BAA_BREAK_GRCONN:
-			{
+			if (au->break_grconn.wire_obj != NULL) {
 				gds_t tmp = {0};
 				csch_oidpath_t oidp = {0};
 				fgw_arg_t args[4], ares;
@@ -224,10 +250,12 @@ static void details_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 				fgw_arg_free(&rnd_fgw, &ares);
 				/* tmp is free'd because it's been passed with FGW_DYN */
 			}
+			else
+				rnd_message(RND_MSG_ERROR, "Can not find the wire to disconnect\n");
 			break;
 
 		case SCH_RND_BAA_MAKE_GRCONN:
-			{
+			if (au->make_grconn.term_obj != NULL) {
 				gds_t tmp = {0};
 				csch_oidpath_t oidp = {0};
 				fgw_arg_t args[4], ares;
@@ -243,10 +271,17 @@ static void details_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 				fgw_arg_free(&rnd_fgw, &ares);
 				/* tmp is free'd because it's been passed with FGW_DYN */
 			}
+			else
+				rnd_message(RND_MSG_ERROR, "Can not find the terminal to connect\n");
 			break;
 
+		case SCH_RND_BAA_LOG:
+			rnd_message(RND_MSG_ERROR, "Tips for this entry:\n%s\n", au->log.str);
+			break;
+
+
 		default:
-			rnd_message(RND_MSG_ERROR, "Can not figure this entry #2\n");
+			rnd_message(RND_MSG_ERROR, "Can not figure this entry (operation not handled in details_cb switch)\n");
 	}
 
 	sch_rnd_backann_auto_free(au);
@@ -330,18 +365,47 @@ static void autofix_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 				csch_sheet_t *sheet = au->attr.grp->hdr.sheet;
 				csch_source_arg_t *source = csch_attrib_src_c(NULL, 0, 0, "back annotation autofix");
 
-				csch_attr_modify_str(sheet, au->attr.grp, -1, au->attr.key, au->attr.want_val, source, 1);
+				if (au->attr.want_val != NULL)
+					csch_attr_modify_str(sheet, au->attr.grp, -1, au->attr.key, au->attr.want_val, source, 1);
+				else
+					csch_attr_modify_del(sheet, au->attr.grp, au->attr.key, 1);
 			}
 			else
 				rnd_message(RND_MSG_ERROR, "Can not modify array type attribute\n");
 			break;
 
 		case SCH_RND_BAA_DEL:
-			csch_op_remove(au->del.obj->sheet, au->del.obj);
+			if (au->del.obj != NULL) {
+				if (!csch_obj_is_deleted(au->del.obj))
+					csch_op_remove(au->del.obj->sheet, au->del.obj);
+			}
+			if (au->del.objlist.used > 0) {
+				long n;
+				for(n = 0; n < au->del.objlist.used; n++) {
+					csch_chdr_t *obj = au->del.objlist.array[n];
+					if (!csch_obj_is_deleted(obj))
+						csch_op_remove(obj->sheet, obj);
+				}
+			}
 			break;
 
 		case SCH_RND_BAA_BREAK_GRCONN:
-			rnd_message(RND_MSG_ERROR, "Graphical connection can not be safely broken by removing a wire\nPlease edit the wirenet manually!\n");
+			if (au->break_grconn.endp == 1) {
+				csch_line_t *wire = (csch_line_t *)au->break_grconn.wire_obj;
+				uundo_freeze_serial(&wire->hdr.sheet->undo);
+				csch_line_modify(wire->hdr.sheet, wire, &au->break_grconn.newx, &au->break_grconn.newy, NULL, NULL, 1, 0, 0);
+				uundo_unfreeze_serial(&wire->hdr.sheet->undo);
+				uundo_inc_serial(&wire->hdr.sheet->undo);
+			}
+			else if (au->break_grconn.endp == 2) {
+				csch_line_t *wire = (csch_line_t *)au->break_grconn.wire_obj;
+				uundo_freeze_serial(&wire->hdr.sheet->undo);
+				csch_line_modify(wire->hdr.sheet, wire, NULL, NULL, &au->break_grconn.newx, &au->break_grconn.newy, 1, 0, 0);
+				uundo_unfreeze_serial(&wire->hdr.sheet->undo);
+				uundo_inc_serial(&wire->hdr.sheet->undo);
+			}
+			else
+				rnd_message(RND_MSG_ERROR, "Graphical connection can not be safely broken by removing a wire\nPlease edit the wirenet manually!\n");
 			break;
 
 		case SCH_RND_BAA_MAKE_GRCONN:
@@ -361,8 +425,12 @@ static void autofix_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 
 			break;
 
+		case SCH_RND_BAA_LOG:
+			rnd_message(RND_MSG_ERROR, "This one needs to be done manually:\n%s\n", au->log.str);
+			break;
+
 		default:
-			rnd_message(RND_MSG_ERROR, "Can not figure this entry #2\n");
+			rnd_message(RND_MSG_ERROR, "Can not figure this entry (operation not handled in autofix_cb switch)\n");
 	}
 
 	sch_rnd_backann_auto_free(au);
