@@ -1,10 +1,10 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  cschem - modular/flexible schematics editor - back annotation parser
+ *  Copyright (C) 2022, 2023 Tibor 'Igor2' Palinkas
  *
- *  (Supported by NLnet NGI0 PET Fund in 2022)
+ *  (Supported by NLnet NGI0 PET Fund in 2022 and Entrust in 2023)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,33 +26,12 @@
  *    mailing list: http://www.repo.hu/projects/sch-rnd/contact.html
  */
 
-/* Parse the old pcb-rnd bap format designed for geda back in 2016 */
+/* Parse the old pcb-rnd bap format designed for geda back in 2016; included
+   from the common line parser */
 
-#include <libcschem/config.h>
-
-#include <stdio.h>
-#include <ctype.h>
-
-#include <librnd/core/safe_fs.h>
-#include <librnd/core/compat_misc.h>
 
 #include "bap_sphash.h"
 
-static void backann_free_entry(sch_rnd_backann_t *ctx, sch_rnd_ba_t *ba)
-{
-	free(ba->raw);
-	ba->raw = NULL;
-	ba->type = SCH_RND_BAT_invalid;
-}
-
-static void backann_free_list(sch_rnd_backann_t *ctx)
-{
-	long n;
-	for(n = 0; n < ctx->list.used; n++)
-		backann_free_entry(ctx, &ctx->list.array[n]);
-	vtba_uninit(&ctx->list);
-}
-
 static char *concat_raw(char **str, int *len, int numstr)
 {
 	int n, totlen = 0;
@@ -192,82 +171,28 @@ static int backann_parse_entry(sch_rnd_backann_t *ctx, sch_rnd_ba_type_t type, c
 	return -1;
 }
 
-static sch_rnd_ba_t *ba_find_conn_del(sch_rnd_backann_t *ctx, const char *net, const char *comp, const char *term)
+static int backann_parse_bap(sch_rnd_backann_t *ctx, char *line, int lineno)
 {
-	long n;
-	for(n = 0; n < ctx->list.used; n++) {
-		sch_rnd_ba_t *ba = &ctx->list.array[n];
-		if (ba->type == SCH_RND_BAT_CONN_DEL) {
-			if ((strcmp(net, ba->value.conn_del.net) == 0) && (strcmp(comp, ba->value.conn_del.comp) == 0) && (strcmp(term, ba->value.conn_del.term) == 0))
-				return ba;
-		}
+	char *args = strpbrk(line, " \t\r\n");
+
+	if (args == NULL) {
+		rnd_message(RND_MSG_ERROR, "backann bap: Invalid command (no args) in %s:%ld\n", ctx->fn, lineno);
+		return 1;
 	}
-	return NULL;
-}
 
-static void backann_postproc(sch_rnd_backann_t *ctx)
-{
-	long n;
-	for(n = 0; n < ctx->list.used; n++) {
-		sch_rnd_ba_t *ba = &ctx->list.array[n];
-		ba->optional = 0;
-		if (ba->type != SCH_RND_BAT_NETINFO) continue;
-		if (ba_find_conn_del(ctx, ba->value.netinfo.net, ba->value.netinfo.comp, ba->value.netinfo.term) != NULL)
-			ba->optional = 1;
+	*args = '\0';
+	args++;
+	while(isspace(*args)) args++;
+
+	switch(backann_bap_sphash(line)) {
+		case backann_bap_net_info:      return backann_parse_net_info(ctx, SCH_RND_BAT_NETINFO, args, lineno);
+		case backann_bap_change_attrib: return backann_parse_entry(ctx, SCH_RND_BAT_COMP_ATTR, args, lineno);
+		case backann_bap_del_conn:      return backann_parse_entry(ctx, SCH_RND_BAT_CONN_DEL, args, lineno);
+		case backann_bap_add_conn:      return backann_parse_entry(ctx, SCH_RND_BAT_CONN_ADD, args, lineno);
+		default:
+			rnd_message(RND_MSG_ERROR, "backann bap: Unknown command '%s' in %s:%ld\n", line, ctx->fn, lineno);
+			return 1;
 	}
-}
 
-static int backann_parse(sch_rnd_backann_t *ctx)
-{
-	FILE *f;
-	char *line, buff[1024];
-	long lineno = 0;
-	int err = 0;
-
-	f = rnd_fopen(&ctx->sheet->hidlib, ctx->fn, "r");
-	if (f == NULL) {
-		rnd_message(RND_MSG_ERROR, "Failed to open back annotation pack '%s'\n", ctx->fn);
-		return -1;
-	}
-
-	while((line = fgets(buff, sizeof(buff), f)) != NULL) {
-		char *args;
-
-		lineno++;
-		while(isspace(*line)) line++;
-		if ((*line == '#') || (*line == '\0')) continue;
-
-		args = strpbrk(line, " \t\r\n");
-		if (args == NULL) {
-			rnd_message(RND_MSG_ERROR, "Invalid command (no args) in %s:%ld\n", ctx->fn, lineno);
-			err = 1;
-			break;
-		}
-		*args = '\0';
-		args++;
-		while(isspace(*args)) args++;
-
-		switch(backann_bap_sphash(line)) {
-			case backann_bap_net_info:      err |= backann_parse_net_info(ctx, SCH_RND_BAT_NETINFO, args, lineno); break;
-			case backann_bap_change_attrib: err |= backann_parse_entry(ctx, SCH_RND_BAT_COMP_ATTR, args, lineno); break;
-			case backann_bap_del_conn:      err |= backann_parse_entry(ctx, SCH_RND_BAT_CONN_DEL, args, lineno); break;
-			case backann_bap_add_conn:      err |= backann_parse_entry(ctx, SCH_RND_BAT_CONN_ADD, args, lineno); break;
-			default:
-				rnd_message(RND_MSG_ERROR, "Unknown command '%s' in %s:%ld\n", line, ctx->fn, lineno);
-				err = 1;
-				break;
-		}
-
-		if (err)
-			break;
-	}
-
-	fclose(f);
-
-	if (err)
-		backann_free_list(ctx);
-	else
-		backann_postproc(ctx);
-
-	return err;
+	return 1;
 }
