@@ -128,7 +128,7 @@ static void abst_export_nets(FILE *f, csch_abstract_t *abs)
 }
 
 
-static int abst_export_project_abst(const char *fn, const char *fmt, csch_abstract_t *abs)
+static int abst_export_project_abst(const char *fn, const char *fmt, csch_abstract_t *abs, rnd_hid_attr_val_t *options)
 {
 	TODO("get hidlib as an arg")
 	rnd_design_t *hidlib = NULL;
