@@ -93,7 +93,7 @@ static void abst_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_va
 		}
 	}
 
-	sch_rnd_export_prj_abst((csch_project_t *)sheet->hidlib.project, sheet, viewid, "abst", options[HA_outfile].str);
+	sch_rnd_export_prj_abst((csch_project_t *)sheet->hidlib.project, sheet, viewid, "abst", options[HA_outfile].str, options);
 }
 
 static int abst_usage(rnd_hid_t *hid, const char *topic)
