@@ -78,7 +78,7 @@ static void tedax_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_v
 		}
 	}
 
-	sch_rnd_export_prj_abst((csch_project_t *)sheet->hidlib.project, sheet, viewid, "tedax", options[HA_outfile].str);
+	sch_rnd_export_prj_abst((csch_project_t *)sheet->hidlib.project, sheet, viewid, "tedax", options[HA_outfile].str, options);
 }
 
 static int tedax_usage(rnd_hid_t *hid, const char *topic)
