@@ -150,8 +150,17 @@ fgw_error_t csch_act_Popup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					x = rnd_grid_fit(x, hidlib->grid, hidlib->grid_ox);
 					y = rnd_grid_fit(y, hidlib->grid, hidlib->grid_oy);
 					obj = sch_rnd_search_first_gui_inspect(sheet, x, y);
-					if (obj == NULL)
-						tn = "none";
+					if (obj == NULL) {
+						if (rnd_point_in_box(&hidlib->dwg, x, y)) {
+							if (sheet->is_symbol)
+								strcpy(name, "/popups/symbol-as-sheet");
+							else
+								strcpy(name, "/popups/sheet");
+							misc = "none";
+						}
+						else
+							tn = "none";
+					}
 					else if (csch_obj_is_grp(obj)) {
 						csch_cgrp_t *grp = (csch_cgrp_t *)obj;
 						if (grp->srole != NULL) {
@@ -512,7 +521,7 @@ static rnd_conf_hid_id_t install_events(const char *cookie, const char *paths[],
 
 int pplg_init_gui(void)
 {
-	const char *st_paths[] = {"editor/line_refraction", "editor/line_cont", "editor/grid", NULL};
+	const char *st_paths[] = {"editor/line_refraction", "editor/line_cont", "editor/rubber_band_mode", "editor/rubber_band_ortho", "editor/grid", NULL};
 	const char *ibpaths[] = { "rc/file_changed_interval", NULL };
 	static rnd_conf_hid_callbacks_t st_cb[sizeof(st_paths)/sizeof(st_paths[0])];
 	static rnd_conf_hid_callbacks_t ibcb[sizeof(ibpaths)/sizeof(ibpaths[0])];
@@ -527,6 +536,7 @@ int pplg_init_gui(void)
 	rnd_event_bind(CSCH_EVENT_SHEET_POSTLOAD, sch_status_postload_ev, NULL, status_cookie);
 	rnd_event_bind(RND_EVENT_CROSSHAIR_MOVE, sch_status_rd_update_ev, NULL, status_cookie);
 	rnd_event_bind(CSCH_EVENT_SHEET_EDITED, sch_status_rd_edit_ev, NULL, status_cookie);
+	rnd_event_bind(CSCH_EVENT_PRJ_STANCE_CHANGED, sch_status_rd_edit_ev, NULL, status_cookie);
 	rnd_event_bind(CSCH_EVENT_SHEET_EDITED, sch_dwg_area_edit_ev, NULL, status_cookie);
 	rnd_event_bind(RND_EVENT_GUI_INIT, pcb_infobar_gui_init_ev, NULL, infobar_cookie);
 	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, pcb_infobar_brdchg_ev, NULL, infobar_cookie);
