@@ -70,7 +70,7 @@ static void status_st_sch2dlg(rnd_design_t *dsg)
 	rnd_hid_cfg_keys_t *kst = rnd_gui->key_state;
 	static rnd_hid_attr_val_t hv;
 	char kbd[128];
-	const char *cnt, *refr;
+	const char *cnt, *refr, *rubber;
 	csch_coord_t grid = (dsg != NULL) ? dsg->grid : 0;
 
 	if (!status.stsub_inited)
@@ -78,8 +78,12 @@ static void status_st_sch2dlg(rnd_design_t *dsg)
 
 	status.buf.used = 0;
 
-	cnt  = conf_core.editor.line_cont ? "C," : "";
-	refr = conf_core.editor.line_refraction ? "|_" : "_|";
+	cnt    = conf_core.editor.line_cont ? "C," : "";
+	refr   = conf_core.editor.line_refraction ? "|_" : "_|";
+	if (conf_core.editor.rubber_band_mode)
+		rubber = conf_core.editor.rubber_band_ortho ? ",RL" : ",R";
+	else
+		rubber = " ";
 
 	if (kst != NULL) {
 		if (kst->seq_len_action > 0) {
@@ -94,9 +98,9 @@ static void status_st_sch2dlg(rnd_design_t *dsg)
 	else
 		*kbd = '\0';
 
-	rnd_append_printf(&status.buf, "grid=%$rc line=%s%s kbd=%s",
+	rnd_append_printf(&status.buf, "grid=%$rc line=%s%s%s kbd=%s",
 		P2C(grid),
-		cnt, refr,
+		cnt, refr, rubber,
 		kbd);
 	hv.str = status.buf.array;
 	rnd_gui->attr_dlg_set_value(status.stsub.dlg_hid_ctx, status.wst, &hv);
