@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - gEDA file format support
+ *  cschem - modular/flexible schematics editor - altium file format support
  *  Copyright (C) 2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 Entrust in 2023)
@@ -588,7 +588,7 @@ static int altium_parse_rect(io_altium_rctx_t *rctx, altium_record_t *rec, int i
 	altium_field_t *field;
 	long pidx = -1, aclr = -1;
 	double x1 = -1, y1 = -1, x2 = -1, y2 = -1, x1f = 0, y1f = 0, x2f = 0, y2f = 0;
-	double xr = -1, yr = -1, xrf = 0, yrf = 0;
+	double xr = 0, yr = 0, xrf = 0, yrf = 0;
 	csch_chdr_t *poly;
 	csch_cgrp_t *parent;
 	char *stroke, *fill;
@@ -619,7 +619,7 @@ static int altium_parse_rect(io_altium_rctx_t *rctx, altium_record_t *rec, int i
 		}
 	}
 
-	if ((x1 < 0) || (y1 < 0) || (x2 < 0) || (y2 < 0)) {
+	if ((x1 < 0) || (y1 < 0)) {
 		error(rec, ("altium_parse_rect(): missing location.x or location.y or corner.x or corner.y\n"));
 		return -1;
 	}
