@@ -46,6 +46,9 @@
 #include <libcschem/cnc_conn.h>
 #include <libcschem/project.h>
 #include <libcschem/util_parse.h>
+
+#include <sch-rnd/util_sheet.h>
+
 #include "read.h"
 
 
@@ -1062,10 +1065,48 @@ static int parse_sheet(read_ctx_t *ctx, lht_node_t *subtree, int load_conf)
 	return 0;
 }
 
+/* Copy only standard, symbol-related pen names from the default sheet */
+static int sym_as_sheet_chk_copy_pen(void *udata, csch_sheet_t *dst, csch_cpen_t *p)
+{
+/*	read_ctx_t *ctx = udata;*/
+	if (strncmp(p->name.str, "busterm-", 8) == 0) return 1;
+	if (strncmp(p->name.str, "term-", 5) == 0) return 1;
+	if (strncmp(p->name.str, "sym-", 4) == 0) return 1;
+	return 0;
+}
+
+static int parse_sym_as_sheet(read_ctx_t *ctx, lht_node_t *root_hash, int load_conf)
+{
+	int res;
+	lht_node_t *grp1;
+
+	/* ctx->sheet->indirect and ctx->sheet->direct are initialized and empty */
+	rnd_trace("SYM LOAD\n");
+
+	grp1 = lht_dom_hash_get(root_hash, "group.1");
+	if (grp1 == NULL) {
+		rnd_message(RND_MSG_ERROR, "Symbol-as-sheet load: group.1 doesn't exist\n");
+		return -1;
+	}
+	if (grp1->type != LHT_HASH) {
+		rnd_message(RND_MSG_ERROR, "Symbol-as-sheet load: group.1 is not a hash\n");
+		return -1;
+	}
+
+
+
+	res = parse_group_(ctx, &ctx->sheet->direct, grp1);
+	if (res == 0) {
+		ctx->sheet->is_symbol = 1;
+		sch_rnd_sheet_setup(ctx->sheet, SCH_RND_SSC_PENS | SCH_RND_SSC_PEN_MARK_DEFAULT, sym_as_sheet_chk_copy_pen, ctx);
+	}
+
+	return res;
+}
 
 /*** file level parsing and entry points ***/
 
-static int io_lihata_load_sheet_or_buff(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst, const char *root_prefix, int root_prefix_len, int load_conf)
+static int io_lihata_load_sheet_or_buff_or_sym(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst, const char *root_prefix, int root_prefix_len, int load_conf, int allow_sym)
 {
 	int res = -1;
 	char *errmsg = NULL;
@@ -1094,6 +1135,12 @@ static int io_lihata_load_sheet_or_buff(FILE *f, const char *fn, const char *fmt
 				csch_sheet_bbox_update(dst);
 		}
 	}
+	else if (allow_sym && (ctx.doc->root->type == LHT_HASH) && (strncmp(ctx.doc->root->name, "cschem-group-v", 14) == 0)) {
+		/* special case: load sym as sheet for direct editing */
+		res = parse_sym_as_sheet(&ctx, ctx.doc->root, load_conf);
+		if (res == 0)
+			csch_sheet_bbox_update(dst);
+	}
 	else {
 		rnd_message(RND_MSG_ERROR, "Error loading '%s': not a %s\n", fn, root_prefix);
 		res = -1;
@@ -1106,12 +1153,12 @@ static int io_lihata_load_sheet_or_buff(FILE *f, const char *fn, const char *fmt
 
 int io_lihata_load_sheet(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst)
 {
-	return io_lihata_load_sheet_or_buff(f, fn, fmt, dst, "cschem-sheet-v", 14, 1);
+	return io_lihata_load_sheet_or_buff_or_sym(f, fn, fmt, dst, "cschem-sheet-v", 14, 1, 1);
 }
 
 int io_lihata_load_buffer(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst)
 {
-	return io_lihata_load_sheet_or_buff(f, fn, fmt, dst, "cschem-buffer-v", 15, 0);
+	return io_lihata_load_sheet_or_buff_or_sym(f, fn, fmt, dst, "cschem-buffer-v", 15, 0, 0);
 }
 
 int io_lihata_load_project(FILE *f, const char *fn, const char *fmt, csch_project_t *dst, int with_sheets)
@@ -1228,7 +1275,10 @@ void test_parse_ev(lht_parse_t *ctx, lht_event_t ev, lht_node_type_t nt, const c
 		else
 			tp->have = 0;
 
-		tp->state = (tp->have & tp->expect) ? TPS_GOOD : TPS_BAD;
+		if ((tp->have == CSCH_IOTYP_GROUP) && (tp->expect == CSCH_IOTYP_SHEET))
+			tp->state = TPS_GOOD; /* special case: loading a symbol group as a sheet for direct editing */
+		else
+			tp->state = (tp->have & tp->expect) ? TPS_GOOD : TPS_BAD;
 	}
 }
 
