@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (lihata format support)
- *  Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2022,2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
  *
@@ -113,7 +113,9 @@ static int lht_save_attribs(write_ctx_t *ctx, int indlev, char *parind, const ht
 					fprintf(ctx->f, "; prio=%d; }\n", a->prio);
 				}
 				else {
-					fprintf(ctx->f, "%s		%s=", parind, a->key);
+					fprintf(ctx->f, "%s		", parind);
+					lht_print_str(ctx->f, a->key);
+					fprintf(ctx->f, "=");
 					lht_print_str(ctx->f, a->val);
 					fprintf(ctx->f, "\n");
 				}
@@ -448,9 +450,17 @@ int lht_save_grp_objects(write_ctx_t *ctx, int indlev, const csch_cgrp_t *grp, v
 
 	ord_objs(ctx, &grp->id2obj, ord);
 	fprintf(ctx->f, "%sli:objects {\n", ind);
-	for(n = 0; n < ord->used; n++)
-		if (lht_print_obj(ctx, indlev+1, ind, ord->array[n]) != 0)
+	for(n = 0; n < ord->used; n++) {
+		csch_chdr_t *obj = ord->array[n];
+
+		if (obj->type == CSCH_CTYPE_PEN) {
+			csch_cpen_t *pen = (csch_cpen_t *)obj;
+			if (pen->copied_from_default)
+				continue; /* happens when saving sheet-as-symbol - skip saving unchanged pens inherited from the default sheet */
+		}
+		if (lht_print_obj(ctx, indlev+1, ind, obj) != 0)
 			return -1;
+	}
 	fprintf(ctx->f, "%s}\n", ind);
 	return 0;
 }
@@ -609,7 +619,7 @@ int io_lihata_save_buffer(const char *fn, const char *fmt, const csch_sheet_t *d
 }
 
 
-int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src)
+int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src, int inhibit_uuid)
 {
 	int r = 0;
 	write_ctx_t ctx;
@@ -620,7 +630,7 @@ int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src)
 		return -1;
 
 	fprintf(ctx.f, "ha:cschem-group-v1 {\n");
-	r |= lht_save_group(&ctx, 1, src, "group", 1, 1);
+	r |= lht_save_group(&ctx, 1, src, "group", 1, inhibit_uuid);
 	fprintf(ctx.f, "}\n");
 
 	fclose(ctx.f);
