@@ -29,5 +29,5 @@
 
 int io_lihata_save_sheet(const char *fn, const char *fmt, const csch_sheet_t *dst);
 int io_lihata_save_buffer(const char *fn, const char *fmt, const csch_sheet_t *dst);
-int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src);
+int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src, int inhibit_uuid);
 
