@@ -1211,7 +1211,7 @@ static int parse_label(read_ctx_t *ctx, void *dst, xmlNode *root)
 	csch_rtree_it_t it;
 	csch_rtree_box_t bbox;
 	csch_sheet_t *sheet = dst;
-	double ox, oy, rot;
+	double ox, oy;
 	long dir, style;
 
 
@@ -1219,7 +1219,7 @@ static int parse_label(read_ctx_t *ctx, void *dst, xmlNode *root)
 	if (parse_long(ctx, root, sdir, &dir, 1) != 0)      return -1;
 	if (parse_long(ctx, root, sstyle, &style, 1) != 0)  return -1;
 	if ((textstr = parse_text(ctx, root, 1)) == NULL)   return -1;
-	rot = rot2deg(ctx, root, dir);
+/*	double rot = rot2deg(ctx, root, dir);*/
 
 	bbox.x1 = csch_alien_coord_x(&ctx->alien, ox) - 1;
 	bbox.y1 = csch_alien_coord_y(&ctx->alien, oy) - 1;
@@ -1246,14 +1246,14 @@ static csch_text_t *parse_text_obj_in(read_ctx_t *ctx, void *dst, xmlNode *root,
 	const char *sstyle = PROP(root, "style");
 	const char *textstr;
 	csch_text_t *text;
-	double ox, oy, rot;
+	double ox, oy;
 	long dir, style = 0;
 
 	if (parse_coords(ctx, root, spos, &ox, &oy) != 0)   return NULL;
 	if (parse_long(ctx, root, sdir, &dir, 1) != 0)      return NULL;
 	if (parse_long(ctx, root, sstyle, &style, 0) != 0)  return NULL;
 	if ((textstr = parse_text(ctx, root, 1)) == NULL)   return NULL;
-	rot = rot2deg(ctx, root, dir);
+/*	double rot = rot2deg(ctx, root, dir);*/
 
 	text = (csch_text_t *)csch_alien_mktext(&ctx->alien, parent, ox, oy, "sheet-decor");
 	text->text = rnd_strdup(textstr);
