@@ -29,7 +29,6 @@
 #include <libcschem/config.h>
 #include <libcschem/libcschem.h>
 #include <libcschem/util_wirenet.h>
-#include <libcschem/cnc_pen.h>
 #include <libcschem/cnc_grp.h>
 #include <libcschem/cnc_arc.h>
 #include <libcschem/cnc_text.h>
@@ -46,6 +45,7 @@
 
 #include <sch-rnd/style.h>
 #include <sch-rnd/sheet.h>
+#include <sch-rnd/util_sheet.h>
 
 #include <plugins/query/query.h>
 #include <plugins/query/query_access.h>
@@ -373,23 +373,9 @@ void csch_alien_append_poly_line(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly_,
 	dst->line.spec.p2.y = CRDY(y2);
 }
 
-
 void csch_alien_sheet_setup(csch_alien_read_ctx_t *ctx, int pen)
 {
-	if (pen != 0) { /* create temp new sheet only if we are to do anything */
-		csch_sheet_t *tmp = sch_rnd_sheet_new((csch_project_t *)ctx->sheet->hidlib.project);
-		if (pen != 0) {
-			htip_entry_t *e;
-			for(e = htip_first(&tmp->direct.id2obj); e != NULL; e = htip_next(&tmp->direct.id2obj, e)) {
-				csch_cpen_t *p = e->value;
-				if (p->hdr.type == CSCH_CTYPE_PEN)
-					csch_pen_dup(ctx->sheet, &ctx->sheet->direct, p);
-			}
-		}
-		minuid_gen(&csch_minuid, ctx->sheet->direct.uuid);
-		minuid_clr(ctx->sheet->direct.data.grp.src_uuid);
-		csch_project_remove_sheet((csch_project_t *)ctx->sheet->hidlib.project, tmp);
-	}
+	sch_rnd_sheet_setup(ctx->sheet, (pen ? SCH_RND_SSC_PENS : 0) | SCH_RND_SSC_UUID, NULL, NULL);
 }
 
 csch_cgrp_t *csch_alien_convert_to_grp(csch_alien_read_ctx_t *ctx, csch_chdr_t **obj)
