@@ -100,6 +100,8 @@ do { \
 	const char *stype = #type; \
 	memcpy(v.type2field_ ## type, (val), sizeof(v.type2field_ ## type)); \
 	prp = csch_props_add(ctx, name, type2TYPE_ ## type, v); \
+	(void)stype; \
+	(void)prp; \
 	exec; \
 } while(0)
 
@@ -149,12 +151,16 @@ static void map_attr(void *ctx, htsp_t *attrs)
 		free(big);
 }
 
+static void map_grp(csch_propedit_t *ctx, csch_cgrp_t *grp, int nogeo);
+
 static void map_sheet(csch_propedit_t *ctx, csch_sheet_t *sheet)
 {
 	map_add_prop(ctx, "p/sheet/loadname", String, sheet->hidlib.loadname);
 	map_add_prop(ctx, "p/sheet/filename", String, sheet->hidlib.fullpath);
 	map_add_prop(ctx, "p/sheet/loose_sym", bool, sheet->loose_sym);
 	map_attr(ctx, &sheet->direct.attr);
+	if (sheet->is_symbol)
+		map_grp(ctx, &sheet->direct, 1);
 }
 
 /* Common properties as per {des3:81} and some extras */
@@ -236,7 +242,7 @@ static void map_poly(csch_propedit_t *ctx, csch_cpoly_t *poly)
 	map_add_prop(ctx, "p/has_fill",      bool,  poly->has_fill);
 }
 
-static void map_grp(csch_propedit_t *ctx, csch_cgrp_t *grp)
+static void map_grp(csch_propedit_t *ctx, csch_cgrp_t *grp, int nogeo)
 {
 	map_attr(ctx, &grp->attr);
 
@@ -248,6 +254,9 @@ TODO("recurse");
 	if (grp->hdr.type == CSCH_CTYPE_GRP)
 		map_add_prop_memcpy(ctx, "p/grp/src_uuid", uuid, grp->data.grp.src_uuid);
 
+	if (nogeo)
+		return;
+
 	map_add_prop(ctx, "p/grp/rot", double, grp->spec_rot);
 	map_add_prop(ctx, "p/grp/mirx", bool, grp->mirx);
 	map_add_prop(ctx, "p/grp/miry", bool, grp->miry);
@@ -297,7 +306,7 @@ static long map_any(void *ctx_, csch_chdr_t *h, const void *udata)
 		case CSCH_CTYPE_POLY:  map_poly(ctx, (csch_cpoly_t *)h); break;
 		case CSCH_CTYPE_TEXT:  map_text(ctx, (csch_text_t *)h); break;
 		case CSCH_CTYPE_GRP_REF:
-		case CSCH_CTYPE_GRP:    map_grp(ctx, (csch_cgrp_t *)h); break;
+		case CSCH_CTYPE_GRP:    map_grp(ctx, (csch_cgrp_t *)h, 0); break;
 		default: return 0;
 	}
 	return 1;
@@ -394,6 +403,8 @@ static void set_attr_obj(csch_propset_ctx_t *st, csch_chdr_t *hdr)
 #define DONE0 { st->set_cnt++; uundo_restore_serial(&st->sheet->undo); return 0; }
 #define DONE1 { st->set_cnt++; uundo_restore_serial(&st->sheet->undo); return 1; }
 
+static void set_grp(csch_propset_ctx_t *st, csch_cgrp_t *grp);
+
 static void set_sheet(csch_propset_ctx_t *st, csch_sheet_t *sheet)
 {
 	if (st->is_attr) {
@@ -401,13 +412,23 @@ static void set_sheet(csch_propset_ctx_t *st, csch_sheet_t *sheet)
 		return;
 	}
 
-	if (st->toggle)
-		return; /* can't toggle anything else */
 
 	if (strncmp(st->name, "p/sheet/", 8) == 0) {
+	const char *pn = st->name + 8;
+
+		if (strcmp(pn, "loose_sym") == 0) {
+			if (st->toggle)
+				st->sheet->loose_sym = !st->sheet->loose_sym;
+			else
+				st->sheet->loose_sym = st->c;
+			DONE;
+		}
+
+		if (st->toggle)
+			return; /* can't toggle anything else */
+
 TODO("sheet prop set");
 #if 0
-	const char *pn = st->name + 8;
 
 		if ((strcmp(pn, "loadname") == 0) &&
 		    (csch_board_change_name(rnd_strdup(st->s)))) DONE;
@@ -419,6 +440,9 @@ TODO("sheet prop set");
 		}
 #endif
 	}
+
+	if (sheet->is_symbol)
+		set_grp(st, &sheet->direct);
 }
 
 /* Common object properties (as in {des3:81}) */
