@@ -44,6 +44,7 @@
 #define MAX_COL 4
 
 static const char *search_acts[] = { "select", "unselect", "view", "count", NULL };
+static const char *search_scopes[] = { "sheet", "project", NULL };
 
 #define NEW_EXPR_LAB "<edit me>"
 
@@ -61,7 +62,7 @@ typedef struct {
 
 typedef struct{
 	RND_DAD_DECL_NOINIT(dlg)
-	int wexpr_str, wwizard, wact;
+	int wexpr_str, wwizard, wact, wscope;
 	int wrowbox[MAX_ROW];
 	int wexpr[MAX_ROW][MAX_COL]; /* expression framed box */
 	int wexpr_lab[MAX_ROW][MAX_COL]; /* the label within the expression box */
@@ -475,7 +476,8 @@ static void search_apply_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	rnd_design_t *hidlib = rnd_gui->get_dad_design(hid_ctx);
 	if (ctx->dlg[ctx->wexpr_str].val.str != NULL) {
 		const char *op = search_acts[ctx->dlg[ctx->wact].val.lng];
-		long res = rnd_actionva(hidlib, "query", search_acts[ctx->dlg[ctx->wact].val.lng], ctx->dlg[ctx->wexpr_str].val.str, NULL);
+		const char *scp = search_scopes[ctx->dlg[ctx->wscope].val.lng];
+		long res = rnd_actionva(hidlib, "query", op, ctx->dlg[ctx->wexpr_str].val.str, scp, NULL);
 		if (strcmp(op, "count") == 0)
 			rnd_message(RND_MSG_INFO, "Advanced search: %ld matched.\n", res);
 	}
@@ -522,6 +524,9 @@ static void search_window_create(void)
 			RND_DAD_LABEL(ctx->dlg, "Action on the results:");
 			RND_DAD_ENUM(ctx->dlg, search_acts);
 				ctx->wact = RND_DAD_CURRENT(ctx->dlg);
+			RND_DAD_LABEL(ctx->dlg, "Scope:");
+			RND_DAD_ENUM(ctx->dlg, search_scopes);
+				ctx->wscope = RND_DAD_CURRENT(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
 		RND_DAD_BEGIN_VBOX(ctx->dlg);
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME | RND_HATF_EXPFILL | RND_HATF_SCROLL);
