@@ -44,6 +44,7 @@
 #include <libcschem/libcschem.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
+#include <librnd/core/project.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/conf_multi.h>
 
@@ -64,13 +65,14 @@ typedef struct renumber_s {
 	int base;            /* start numbering from */
 	const char *sorta;
 	unsigned selected:1; /* renumber selected only */
+	unsigned inprj:1;    /* operate on the whole project */
 } renumber_t;
 
 #include "renumber_impl.c"
 #include "renumber_dlg.c"
 
-const char csch_acts_Renumber[] = "Renumber(selected|all, lr|rl|tb|bt, [base])\n";
-const char csch_acth_Renumber[] = "";
+const char csch_acts_Renumber[] = "Renumber(Selected|All|SelectedProject|AllProject, lr|rl|tb|bt, [base])\n";
+const char csch_acth_Renumber[] = "Rename (renumber) selected or all symbols on current sheet or on all sheets of the project. Second argument is the direction of numbering (e.g. rl means right-to-left). If base is specified, it is an integer and is the first number assigned. Non-numerical name prefix is preserved (R, C, etc.)";
 fgw_error_t csch_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	rnd_design_t *hl = RND_ACT_DESIGN;
@@ -94,8 +96,15 @@ fgw_error_t csch_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		case F_Selected:
 			rctx.selected = 1;
 			break;
+		case F_SelectedProject:
+			rctx.selected = 1;
+			rctx.inprj = 1;
+			break;
 		case F_All:
 			break;
+		case F_AllProject:
+			rctx.inprj = 1;
+			break;
 		default:
 			rnd_message(RND_MSG_ERROR, "Renumber: invalid first argument\n");
 			goto error;
@@ -129,7 +138,7 @@ fgw_error_t csch_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 const char csch_acts_RenumberDialog[] = "RenumberDialog()\n";
-const char csch_acth_RenumberDialog[] = "";
+const char csch_acth_RenumberDialog[] = "Open the graphical frontend dialog box for the Renumber() action. The dialog box is single instance and non-modal.";
 fgw_error_t csch_act_RenumberDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	sch_rnd_dlg_renumdlg();
