@@ -34,7 +34,8 @@
 
 #include <sch-rnd/build_run.h>
 
-static const char *scopes[] = {"all", "selected", NULL};
+static const char *scope_names[] = {"all on sheet", "selected on sheet", "all in project", "selected in project", NULL};
+static const char *scopes[] = {"all", "selected", "allProject", "selectedProject", NULL};
 static const char *sorts[]  = {"left->right (top->bottom within)", "right->left (top->bottom within)", "top->bottom (left->right within)", "bottom->top (left->right within)", NULL };
 static const char *sorts2[] = {"lr", "rl", "tb", "bt", NULL};
 
@@ -81,7 +82,7 @@ static void sch_rnd_dlg_renumdlg(void)
 		RND_DAD_BEGIN_HBOX(renumdlg_ctx.dlg);
 			RND_DAD_LABEL(renumdlg_ctx.dlg, "Scope:");
 				RND_DAD_HELP(renumdlg_ctx.dlg, hscope);
-			RND_DAD_ENUM(renumdlg_ctx.dlg, scopes);
+			RND_DAD_ENUM(renumdlg_ctx.dlg, scope_names);
 				renumdlg_ctx.wscope = RND_DAD_CURRENT(renumdlg_ctx.dlg);
 				RND_DAD_HELP(renumdlg_ctx.dlg, hscope);
 		RND_DAD_END(renumdlg_ctx.dlg);
