@@ -51,6 +51,8 @@ void aattr_dlg_ahist2dlg(abst_attrdlg_ctx_t *actx, csch_ahdr_t *aobj)
 	rnd_hid_row_t *r, *bestr = NULL;
 	const char *aattr_name = NULL;
 	long best = 65537;
+	const char *export_name = NULL;
+	rnd_hid_attr_val_t hv;
 
 	/* get abstract attr selected */
 	r = rnd_dad_tree_get_selected(aattr);
@@ -66,6 +68,8 @@ void aattr_dlg_ahist2dlg(abst_attrdlg_ctx_t *actx, csch_ahdr_t *aobj)
 			long n, v;
 			char *cell[2];
 
+			export_name = a->export_name; /* side effect: display export name later */
+
 			cell[1] = NULL;
 			for(n = 0; n < a->source.used; n++) {
 				cell[0] = rnd_strdup(a->source.array[n]);
@@ -80,10 +84,13 @@ void aattr_dlg_ahist2dlg(abst_attrdlg_ctx_t *actx, csch_ahdr_t *aobj)
 	}
 
 	if (bestr != NULL) {
-		rnd_hid_attr_val_t hv;
 		hv.str = bestr->path;
 		rnd_gui->attr_dlg_set_value(*actx->dlg_hid_ctx, actx->wahistory, &hv);
 	}
+
+	/* side effect: display export name */
+	hv.str = (export_name == NULL) ? "" : export_name;
+	rnd_gui->attr_dlg_set_value(*actx->dlg_hid_ctx, actx->wexport_name, &hv);
 }
 
 static void aattr_dlg_sheet2dlg_abst_net(abst_attrdlg_ctx_t *actx, csch_anet_t *anet)
