@@ -370,7 +370,7 @@ void sch_rnd_abst_dlg(csch_project_t *prj, long aid, const char *attr_name)
 
 			RND_DAD_BEGIN_VBOX(ctx->dlg); /* right */
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-				aattr_dlg_create(&ctx->right, ctx->dlg, prj);
+				aattr_dlg_create(&ctx->right, ctx->dlg, prj, NULL);
 				RND_DAD_BUTTON_CLOSES(ctx->dlg, clbtn);
 			RND_DAD_END(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
