@@ -691,6 +691,23 @@ static void attr_floater_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	csch_auto_attr_place(ctx->sheet, grp, r->cell[0], penname, NULL, ctx->ch_xy);
 }
 
+static void attr_afloater_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	attrdlg_ctx_t *ctx = caller_data;
+	rnd_hid_attribute_t *tattr = &ctx->dlg[ctx->right.waattrs];
+	rnd_hid_row_t *r = rnd_dad_tree_get_selected(tattr);
+	csch_cgrp_t *grp = (csch_cgrp_t *)ctx->obj;
+	const char *penname;
+	char *templ;
+
+	penname = (grp->role == CSCH_ROLE_WIRE_NET ? "wire" : "sym-secondary");
+
+	templ = rnd_strdup_printf("%%../a.%s%%", r->cell[0]); /* use the abstract attribute */
+	csch_auto_attr_place(ctx->sheet, grp, r->cell[0], penname, templ, ctx->ch_xy);
+	free(templ);
+}
+
+
 
 static void attr_del_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
@@ -831,6 +848,7 @@ static const char *attr_dlg(csch_sheet_t *sheet, csch_cgrp_t *obj, const char *t
 							RND_DAD_BUTTON(ctx->dlg, "Floater");
 								ctx->wfloater = RND_DAD_CURRENT(ctx->dlg);
 								RND_DAD_CHANGE_CB(ctx->dlg, attr_floater_cb);
+								RND_DAD_HELP(ctx->dlg, "Create a floater text that prints the value of the attribute\nfrom the concrete model (value before compilation)");
 							spring(ctx);
 							RND_DAD_BUTTON(ctx->dlg, "New");
 								RND_DAD_CHANGE_CB(ctx->dlg, attr_new_cb);
@@ -921,7 +939,7 @@ static const char *attr_dlg(csch_sheet_t *sheet, csch_cgrp_t *obj, const char *t
 
 			RND_DAD_BEGIN_VBOX(ctx->dlg); /* top right */
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-				aattr_dlg_create(&ctx->right, ctx->dlg, (csch_project_t *)sheet->hidlib.project);
+				aattr_dlg_create(&ctx->right, ctx->dlg, (csch_project_t *)sheet->hidlib.project, attr_afloater_cb);
 			RND_DAD_END(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
 
@@ -991,6 +1009,9 @@ RND_INLINE csch_chdr_t *resolve_obj_(csch_sheet_t *sheet, const char *actname, c
 			return &csch_obj_clicked->parent->hdr;
 		}
 	}
+	else if (strcmp(cmd, "sheet") == 0) {
+		return &sheet->direct.hdr;
+	}
 	else if (strncmp(cmd, "object", 6) == 0) {
 		if (cmd[6] == ':') {
 			csch_chdr_t *obj;
@@ -1042,7 +1063,7 @@ csch_chdr_t *sch_dialog_resolve_obj(csch_sheet_t *sheet, const char *actname, co
 }
 
 
-const char csch_acts_AttributeDialog[] = "AttributeDialog([last-click|parent|object[:idpath]], [target_key])";
+const char csch_acts_AttributeDialog[] = "AttributeDialog([last-click|parent|sheet|object[:idpath]], [target_key])";
 const char csch_acth_AttributeDialog[] = "Bring up the Attribute Editor Dialog for an object.\n";
 fgw_error_t csch_act_AttributeDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
