@@ -38,9 +38,9 @@
 #include <librnd/core/event.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/hidlib.h>
-#include <librnd/core/hidlib_conf.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
+#include <librnd/core/rnd_conf.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/compat_fs.h>
 #include <librnd/core/globalconst.h>
@@ -56,6 +56,7 @@
 #include <sch-rnd/search.h>
 #include <sch-rnd/funchash_core.h>
 #include <sch-rnd/crosshair.h>
+#include <sch-rnd/dad.h>
 
 #include "timed_chg.h"
 
@@ -195,20 +196,20 @@ static void pen2dlg(pendlg_ctx_t *ctx, csch_cpen_t *pen)
 
 	if (pen != NULL) {
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wname, str, pen->name.str);
-		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wsize, lng, pen->size);
+		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wsize, crd, C2P(pen->size));
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wshape, lng, pen->shape);
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wcolor, clr, pen->color);
-		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontheight, lng, pen->font_height);
+		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontheight, crd, C2P(pen->font_height));
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontfamily, str, RND_EMPTY(pen->font_family));
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontstyle, str,  RND_EMPTY(pen->font_style));
 		enab = 1;
 	}
 	else {
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wname, str, "");
-		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wsize, lng, 0);
+		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wsize, crd, 0);
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wshape, lng, -1);
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wcolor, str, "");
-		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontheight, lng, 0);
+		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontheight, crd, 0);
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontfamily, str, "");
 		RND_DAD_SET_VALUE(ctx->dlg_hid_ctx, ctx->wfontstyle, str, "");
 		enab = 0;
@@ -265,11 +266,23 @@ static void pen_new_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 
 	pendlg_finalize(ctx);
 
+	uundo_freeze_serial(&ctx->sheet->undo);
 	pen = (csch_cpen_t *)csch_op_create(ctx->sheet, ctx->grp, CSCH_CTYPE_PEN);
 	if (pen != NULL) {
+		rnd_color_t clr;
+		csch_coord_t sz = 1000, tsz=3000;
+		char *font_family = "sans";
+
+		memcpy(&clr, rnd_color_red, sizeof(rnd_color_t));
+		csch_pen_modify_tip(ctx->sheet, pen, NULL, &sz, &clr, NULL, NULL, NULL, 1);
+		csch_pen_modify_font(ctx->sheet, pen, &tsz, &font_family, NULL, 1);
 		pen_dlg_remap_redraw(ctx);
+		ctx->last_pen = pen;
 		pen_dlg_select_by_name(ctx, pen->name.str);
+		pen2dlg(ctx, pen);
 	}
+	uundo_unfreeze_serial(&ctx->sheet->undo);
+	uundo_inc_serial(&ctx->sheet->undo);
 }
 
 static void pen_del_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -292,15 +305,23 @@ static void set_pen_tip_timed(void *ctx_)
 	pendlg_ctx_t *ctx = ctx_;
 	char *tmp_name, **new_name = NULL;
 	csch_pen_shape_t tmp_shape, *new_shape = NULL;
-	csch_coord_t *new_size = NULL;
+	csch_coord_t *new_size = NULL, crdtmp;
 	rnd_color_t *new_color = NULL;
 	int remap = 0;
 
 	if (ctx->tip.name) {
+		rnd_hid_attribute_t *attr = &ctx->dlg[ctx->wlist];
+		rnd_hid_row_t *r;
+
 		tmp_name = rnd_strdup(ctx->dlg[ctx->wname].val.str);
 		new_name = &tmp_name;
 		ctx->font.style = 0;
 		remap = 0;
+
+		/* update name in the list-of-pens */
+		r = rnd_dad_tree_get_selected(attr);
+		if (r != NULL)
+			rnd_dad_tree_modify_cell(attr, r, 0, rnd_strdup(tmp_name));
 	}
 
 	if (ctx->tip.shape) {
@@ -310,7 +331,8 @@ static void set_pen_tip_timed(void *ctx_)
 	}
 
 	if (ctx->tip.size) {
-		new_size = &ctx->dlg[ctx->wsize].val.lng;
+		crdtmp = P2C(ctx->dlg[ctx->wsize].val.crd);
+		new_size = &crdtmp;
 		ctx->tip.size = 0;
 	}
 
@@ -383,10 +405,11 @@ static void set_pen_font_timed(void *ctx_)
 {
 	pendlg_ctx_t *ctx = ctx_;
 	char *tmp_style, **new_style = NULL, *tmp_family, **new_family = NULL;
-	csch_coord_t *new_height = NULL;
+	csch_coord_t *new_height = NULL, ctmp;
 
 	if (ctx->font.height) {
-		new_height = &ctx->dlg[ctx->wfontheight].val.lng;
+		ctmp = P2C(ctx->dlg[ctx->wfontheight].val.crd);
+		new_height = &ctmp;
 		ctx->font.height = 0;
 	}
 
@@ -410,8 +433,9 @@ static void set_pen_fontheight_cb(void *hid_ctx, void *caller_data, rnd_hid_attr
 {
 	pendlg_ctx_t *ctx = caller_data;
 	csch_cpen_t *pen = get_dlg_pen(ctx);
+	csch_coord_t newval = P2C(ctx->dlg[ctx->wfontheight].val.crd);
 
-	if ((pen == NULL) || (ctx->dlg[ctx->wfontheight].val.lng == pen->font_height))
+	if ((pen == NULL) || (newval == pen->font_height))
 		return;
 
 	ctx->font.pen = pen;
@@ -493,9 +517,9 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-		RND_DAD_BEGIN_HPANE(ctx->dlg);
+		RND_DAD_BEGIN_HPANE(ctx->dlg, "left-right");
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-			RND_DAD_SET_PANE_NAME(ctx->dlg, "left-right");
+
 			RND_DAD_BEGIN_VBOX(ctx->dlg); /* left */
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 				RND_DAD_TREE(ctx->dlg, 2, 0, hdr); /* top left: tree */
@@ -531,9 +555,8 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 
 				RND_DAD_BEGIN_HBOX(ctx->dlg);
 					RND_DAD_LABEL(ctx->dlg, "Size:");
-					RND_DAD_INTEGER(ctx->dlg);
+					RND_DAD_CSCH_COORD(ctx->dlg);
 						ctx->wsize = RND_DAD_CURRENT(ctx->dlg);
-						RND_DAD_MINMAX(ctx->dlg, 0, 100000);
 						RND_DAD_CHANGE_CB(ctx->dlg, set_pen_size_cb);
 				RND_DAD_END(ctx->dlg);
 
@@ -546,7 +569,7 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 
 				RND_DAD_BEGIN_HBOX(ctx->dlg);
 					RND_DAD_LABEL(ctx->dlg, "Font height:");
-					RND_DAD_INTEGER(ctx->dlg);
+					RND_DAD_CSCH_COORD(ctx->dlg);
 						ctx->wfontheight = RND_DAD_CURRENT(ctx->dlg);
 						RND_DAD_CHANGE_CB(ctx->dlg, set_pen_fontheight_cb);
 				RND_DAD_END(ctx->dlg);
@@ -612,7 +635,7 @@ const char csch_acts_PenDialog[] = "PenDialog([object[=idpath]], [non-modal], [r
 const char csch_acth_PenDialog[] = "Bring up a modal pen selecton dialog. If idpath is specified, list pens starting from the group addressed by idpath. If second argument is non-modal, the dialog is not modal; else it is modal and the user selected pen is returned (as idpath). If recursive is set, map pens of parents as well. If ret_name is set, return the name of the selected pen (or NULL on no selection) instead of the usual integer return. If init_pen_name is supplied, the cursor is set to that pen.\n";
 fgw_error_t csch_act_PenDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	rnd_hidlib_t *hidlib = RND_ACT_HIDLIB;
+	rnd_design_t *hidlib = RND_ACT_DESIGN;
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
 	int cmd, is_modal = 1, recursive = 0, ret_name = 0;
 	const char *modals = NULL, *recursives = NULL, *ret_names = NULL;
