@@ -463,7 +463,6 @@ void sch_dlg_pref_lib_create(pref_ctx_t *ctx, rnd_design_t *dsg)
 {
 	DEF_TABDATA;
 	static const char *hdr[] = {"configured path", "actual path on the filesystem", "config source", NULL};
-	rnd_hid_tree_t *tree;
 
 	RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL); /* get the parent vbox, which is the tab's page vbox, to expand and fill */
 
@@ -474,7 +473,7 @@ void sch_dlg_pref_lib_create(pref_ctx_t *ctx, rnd_design_t *dsg)
 		RND_DAD_TREE(ctx->dlg, 3, 0, hdr);
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL | RND_HATF_SCROLL);
 			tabdata->wlist = RND_DAD_CURRENT(ctx->dlg);
-			tree = ctx->dlg[tabdata->wlist].wdata;
+			/* rnd_hid_tree_t *tree = ctx->dlg[tabdata->wlist].wdata; */
 			RND_DAD_TREE_SET_CB(ctx->dlg, selected_cb, pref_lib_select_cb);
 	RND_DAD_END(ctx->dlg);
 
