@@ -440,7 +440,7 @@ static void tree_anyedit_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	csch_chdr_t *obj = get_dlg_obj(ctx, 0);
 
 	if (obj != NULL) {
-		rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
+		rnd_design_t *hl = &obj->sheet->hidlib;
 		char *arg, *oidp;
 
 		oidp = csch_chdr_to_oidpath_str(obj);
