@@ -260,7 +260,7 @@ static void view_eng_edit(void *hid_ctx, void *caller_data, int op)
 		}
 		neng = csch_eng_alloc(view, name, name, options);
 		if (neng == NULL) {
-			rnd_message(RND_MSG_ERROR, "dlg_view internal error: failed to create engine binding '%s' for view\n", name);
+			rnd_message(RND_MSG_ERROR, "dlg_view internal error: failed to create engine binding '%s' for view\nThere is probably no engine by that name (typo? missnig plugin?)\n", name);
 			free(name);
 			return;
 		}
@@ -297,7 +297,7 @@ static void view_eng_edit(void *hid_ctx, void *caller_data, int op)
 	if (sch_rnd_project_view_lib2lht(view) != 0)
 		rnd_message(RND_MSG_ERROR, "dlg_view internal error: failed to save view changes in project lihata");
 
-	sch_rnd_project_flush();
+	csch_project_flush();
 	view_view2dlg(ctx);
 }
 
