@@ -47,6 +47,8 @@
 #include "dlg_attrib.h"
 #include "dlg_about.h"
 #include "dlg_abstract.h"
+#include "dlg_stance.h"
+#include "dlg_cond.h"
 #include "dlg_undo.h"
 #include "dlg_pen.h"
 #include "dlg_text.h"
@@ -79,8 +81,12 @@ static rnd_action_t sch_dialogs_action_list[] = {
 	{"ViewDialog", csch_act_ViewDialog, csch_acth_ViewDialog, csch_acts_ViewDialog},
 	{"ProjectDialog", csch_act_ProjectDialog, csch_acth_ProjectDialog, csch_acts_ProjectDialog},
 	{"About", csch_act_About, csch_acth_About, csch_acts_About},
+	{"StanceDialog", csch_act_StanceDialog, csch_acth_StanceDialog, csch_acts_StanceDialog},
+	{"ConditionalDialog", csch_act_ConditionalDialog, csch_acth_ConditionalDialog, csch_acts_ConditionalDialog},
 
 	{"quick_attr_role", csch_act_quick_attr_role, csch_acth_quick_attr_role, csch_acts_quick_attr_role},
+	{"quick_attr_forge__if__dnp", csch_act_quick_attr_forge__if__dnp_omit, csch_acth_quick_attr_forge__if__dnp, csch_acts_quick_attr_forge__if__dnp},
+	{"quick_attr_forge__if__omit", csch_act_quick_attr_forge__if__dnp_omit, csch_acth_quick_attr_forge__if__omit, csch_acts_quick_attr_forge__if__omit},
 	{"QuickAttr", csch_act_QuickAttr, csch_acth_QuickAttr, csch_acts_QuickAttr},
 	{"QuickAttrEditable", csch_act_QuickAttrEditable, csch_acth_QuickAttrEditable, csch_acts_QuickAttrEditable}
 };
@@ -96,6 +102,7 @@ static void csch_dlg_ev_preunload(rnd_design_t *hidlib, void *user_data, int arg
 	csch_dlg_attr_preunload(sheet);
 	csch_dlg_library_preunload(sheet);
 	csch_dlg_tree_chg_sheet(sheet);
+	csch_dlg_cond_preunload(sheet);
 }
 
 static void csch_dlg_ev_sheet_edit(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
@@ -149,6 +156,8 @@ void pplg_uninit_sch_dialogs(void)
 	rnd_remove_actions_by_cookie(sch_dialogs_cookie);
 	csch_dlg_tree_uninit();
 	csch_dlg_abst_uninit();
+	csch_dlg_stance_uninit();
+	csch_dlg_cond_uninit();
 	csch_dlg_library_uninit();
 	sch_rnd_attr_quick_uninit();
 	rnd_dlg_pref_uninit();
@@ -164,6 +173,8 @@ int pplg_init_sch_dialogs(void)
 	rnd_dlg_pref_init(sch_dlg_pref_tab, sch_dlg_pref_first_init);
 	csch_dlg_tree_init();
 	csch_dlg_abst_init();
+	csch_dlg_stance_init();
+	csch_dlg_cond_init();
 	csch_dlg_library_init();
 	csch_dlg_undo_init();
 	rnd_event_bind(CSCH_EVENT_SHEET_PREUNLOAD, csch_dlg_ev_preunload, NULL, sch_dialogs_cookie);
