@@ -51,6 +51,10 @@ RND_INLINE void csch_timed_chg_schedule(csch_timed_chg_t *chg);
 /* if timer is active, force-call it and stop it */
 RND_INLINE void csch_timed_chg_finalize(csch_timed_chg_t *chg);
 
+/* stop the timer without calling back anything */
+RND_INLINE void csch_timed_chg_cancel(csch_timed_chg_t *chg);
+
+
 /* Creates a "pending" label; when the dialog box is created, call
    csch_timed_chg_timing_init() */
 #define CSCH_DAD_TIMING(dlg, chg, what) \
@@ -94,6 +98,14 @@ RND_INLINE void csch_timed_chg_finalize(csch_timed_chg_t *chg)
 	}
 }
 
+RND_INLINE void csch_timed_chg_cancel(csch_timed_chg_t *chg)
+{
+	if (!chg->active)
+		return;
+
+	rnd_gui->stop_timer(rnd_gui, chg->timer);
+}
+
 RND_INLINE void csch_timed_chg_schedule(csch_timed_chg_t *chg)
 {
 	rnd_hidval_t user_data;
