@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - standard device mapper
- *  Copyright (C) 2019,2020,2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2020,2022,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -75,8 +75,8 @@ fgw_error_t devmap_symbol_joined_comp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 fgw_error_t devmap_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	fgw_obj_t *obj = argv[0].val.argv0.func->obj;
-	devmap_ctx_t *ctx = obj->script_data;
+	csch_project_t *prj;
+	anymap_ctx_t *actx;
 	csch_hook_call_ctx_t *cctx = argv[0].val.argv0.user_call_ctx;
 	csch_acomp_t *comp;
 	csch_attribs_t *comp_attrs;
@@ -91,7 +91,11 @@ fgw_error_t devmap_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (adevmap == NULL)
 		return 0;
 
-	comp_attrs = devmap_get_from_any_lib(ctx, comp, adevmap, argv[0].val.argv0.user_call_ctx);
+
+	prj = comp->hdr.abst->prj;
+	actx = csch_p4_get_by_project(&p4_devmap, prj);
+
+	comp_attrs = anymap_get_from_any_lib(actx, comp, adevmap, argv[0].val.argv0.user_call_ctx);
 	if (comp_attrs == NULL) {
 		rnd_message(RND_MSG_ERROR, "Can't find devmap %s for component %s\n", (adevmap->val == NULL ? "<null>" : adevmap->val), comp->name);
 		return -1;
