@@ -54,6 +54,7 @@ static const char std_tools_cookie[] = "std_tools";
 #include "tool_remove.c"
 #include "tool_rotate.c"
 #include "tool_movecopy.c"
+#include "tool_polyedit.c"
 #include "tool_text.c"
 #include "tool_lock.c"
 #include "tool_mirror.c"
@@ -85,6 +86,7 @@ int pplg_init_std_tools(void)
 
 	rnd_tool_reg(&sch_rnd_tool_move, std_tools_cookie);
 	rnd_tool_reg(&sch_rnd_tool_copy, std_tools_cookie);
+	rnd_tool_reg(&sch_rnd_tool_polyedit, std_tools_cookie);
 
 	return 0;
 }
