@@ -44,9 +44,14 @@ static void tool_wirenet_press(rnd_design_t *hl)
 
 static void tool_wirenet_release(rnd_design_t *hl)
 {
-	if (line_release(hl)) {
-		csch_sheet_t *sheet = (csch_sheet_t *)hl;
+	csch_sheet_t *sheet = (csch_sheet_t *)hl;
 
+	if (sheet->is_symbol) {
+		rnd_message(RND_MSG_ERROR, "Can't draw wirenets in symbol edit mode\n");
+		return;
+	}
+
+	if (line_release(hl)) {
 		if (line_is_zero_len()) {
 			csch_tool_line.clicked = 0;
 			return;
