@@ -49,6 +49,7 @@
 #include <librnd/core/error.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/actions.h>
+#include <librnd/hid/hid.h>
 
 #include <sch-rnd/conf_core.h>
 
@@ -66,7 +67,7 @@ static int ll_keyeqna(const void *obj1, const void *obj2)  { return csch_cobj_ke
    indirect/purpose=symbol group's backend_data->ptr[0]; [1] is the version
    without attribute matching. Also remember our local root group in ptr[2].
 */
-static void symlib_local_sheet_init(rnd_hidlib_t *hl, csch_lib_t *root_dir, const csch_cgrp_t *symlib)
+static void symlib_local_sheet_init(rnd_design_t *hl, csch_lib_t *root_dir, const csch_cgrp_t *symlib)
 {
 	root_dir->backend_data.ptr[0] = htpi_alloc(ll_hash, ll_keyeq);
 	root_dir->backend_data.ptr[1] = htpi_alloc(ll_hashna, ll_keyeqna);
@@ -123,7 +124,7 @@ static int symlib_local_insert_sym(csch_lib_t *root_dir, htpi_t *sh, htpi_t *shn
 	return res;
 }
 
-static int symlib_local_map_local_(rnd_hidlib_t *hl, csch_lib_t *root_dir, csch_cgrp_t *symlib)
+static int symlib_local_map_local_(rnd_design_t *hl, csch_lib_t *root_dir, csch_cgrp_t *symlib)
 {
 	htip_entry_t *e;
 	htpi_t *sh = root_dir->backend_data.ptr[0];
@@ -137,7 +138,7 @@ static int symlib_local_map_local_(rnd_hidlib_t *hl, csch_lib_t *root_dir, csch_
 	return 0;
 }
 
-static int symlib_local_map_local(rnd_hidlib_t *hl, csch_lib_t *root_dir, const csch_cgrp_t *indirect)
+static int symlib_local_map_local(rnd_design_t *hl, csch_lib_t *root_dir, const csch_cgrp_t *indirect)
 {
 	csch_cgrp_t *grp = csch_loclib_get_root((csch_sheet_t *)hl, loclib_master, NULL, 0, NULL);
 	if (grp != NULL) {
@@ -360,7 +361,7 @@ static void local_paste_place(csch_sheet_t *sheet, csch_cgrp_t **grp)
 }
 
 /* Perform a "place a ref from local lib" when pasting a symbol from the buffer */
-static void symlib_local_paste(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void symlib_local_paste(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
 	csch_chdr_t **obj = argv[1].d.p;
@@ -426,7 +427,7 @@ static void symlib_local_paste(rnd_hidlib_t *hidlib, void *user_data, int argc,
 
 /* Perform a "copy to buffer" on local lib refs: need to include the referenced
    group from local lib into buffer's indirect so the buffer is self-contained */
-static void symlib_local_copy(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void symlib_local_copy(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	csch_chdr_t **obj = argv[1].d.p;
 	csch_cgrp_t *src, *symlib, *newg, *newr, *bsymlib;
@@ -487,7 +488,7 @@ static void symlib_local_copy(rnd_hidlib_t *hidlib, void *user_data, int argc, r
 #include "loc_ops.c"
 #include "loc_acts.c"
 
-static void symlib_local_sheet_postload_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void symlib_local_sheet_postload_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
 	csch_lib_add_local(sheet, loclib_master);
