@@ -54,6 +54,7 @@
 #include <libcschem/util_lib_fs.h>
 
 #include <plugins/sch_dialogs/quick_attr_util.h>
+#include <plugins/lib_target/lib_target.h>
 
 #include "htcp.h"
 #include "target_spice_conf.h"
@@ -76,7 +77,7 @@ typedef struct spicelib_s {
 	gds_t *text;
 } spicelib_t;
 
-static spicelib_ctx_t *global_spicelib_ctx;
+static spicelib_ctx_t *global_spicelib_ctx = NULL;
 
 static const char cookie[] = "target_spice";
 static const char spicelib_cookie[] = "target_spice/spicelib";
@@ -84,7 +85,7 @@ static csch_lib_backend_t be_spicelib_mod;
 static csch_lib_master_t *spicelibmaster;
 
 const char csch_acts_quick_attr_spice__model[] = "quick_attr_spice__model(objptr)";
-const char csch_acth_quick_attr_spice__model[] = "Qucik Attribute Edit for spice/model using the devmap library";
+const char csch_acth_quick_attr_spice__model[] = "Quick Attribute Edit for spice/model using the devmap library";
 fgw_error_t csch_act_quick_attr_spice__model(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	rnd_design_t *hidlib = RND_ACT_DESIGN;
@@ -129,7 +130,7 @@ fgw_error_t csch_act_quick_attr_spice__model(fgw_arg_t *res, int argc, fgw_arg_t
 static void spicelib_sheet_postload_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
-	csch_lib_add_all(sheet, spicelibmaster, &target_spice_conf.plugins.target_spice.search_paths);
+	csch_lib_add_all(sheet, spicelibmaster, &target_spice_conf.plugins.target_spice.search_paths, 0);
 	csch_lib_add_local(sheet, spicelibmaster);
 }
 
@@ -328,6 +329,20 @@ static csch_acomp_t *make_acomp_for_model_card(spicelib_ctx_t *ctx, csch_acomp_t
 	return modcomp;
 }
 
+fgw_error_t target_spice_compile_component0(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	fgw_obj_t *obj = argv[0].val.argv0.func->obj;
+	spicelib_ctx_t *ctx = obj->script_data;
+	csch_view_eng_t *eng = ctx->eng;
+	csch_acomp_t *comp;
+
+	CSCH_HOOK_CONVARG(1, FGW_AOBJ, std_cschem_comp_update, comp = fgw_aobj(&argv[1]));
+
+	sch_trgt_copy_alt_attrib(&comp->hdr, eng->eprio + CSCH_PRI_PLUGIN_NORMAL, "target_spice", "display/omit",   "spice/omit", "omit", NULL);
+	return 0;
+}
+
+
 fgw_error_t target_spice_compile_component1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 /*	csch_hook_call_ctx_t *cctx = argv[0].val.argv0.user_call_ctx;*/
@@ -346,6 +361,7 @@ fgw_error_t target_spice_compile_component1(fgw_arg_t *res, int argc, fgw_arg_t
 	CSCH_HOOK_CONVARG(1, FGW_AOBJ, std_cschem_comp_update, comp = fgw_aobj(&argv[1]));
 	assert(comp->hdr.type == CSCH_ATYPE_COMP);
 
+
 	model_card = csch_attrib_get_str(&comp->hdr.attr, "spice/model_card");
 	if (model_card != NULL) {
 		char *uname = rnd_concat("schrnd_", comp->name, NULL);
@@ -729,6 +745,19 @@ static void install_scalar_bridges(spicelib_ctx_t *ctx, csch_abstract_t *abst, c
 
 }
 
+static void target_spice_gen_net_omits(spicelib_ctx_t *ctx, csch_abstract_t *abst)
+{
+	htsp_entry_t *e;
+	csch_view_eng_t *eng = ctx->eng;
+
+	for(e = htsp_first(&abst->nets); e != NULL; e = htsp_next(&abst->nets, e)) {
+		csch_anet_t *net = e->value;
+
+		sch_trgt_copy_alt_attrib(&net->hdr, eng->eprio + CSCH_PRI_PLUGIN_NORMAL, "target_spice", "display/omit",   "spice/omit", "omit", NULL);
+	}
+}
+
+
 fgw_error_t target_spice_compile_project_after(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 /*	csch_hook_call_ctx_t *cctx = argv[0].val.argv0.user_call_ctx;*/
@@ -747,6 +776,7 @@ fgw_error_t target_spice_compile_project_after(fgw_arg_t *res, int argc, fgw_arg
 		default: /* no bridges inserted */ ;
 	}
 	elect_net_zero(ctx, abst);
+	target_spice_gen_net_omits(ctx, abst);
 
 	ctx->compiling = 0;
 
@@ -759,6 +789,7 @@ static int on_load(fgw_obj_t *obj, const char *filename, const char *opts)
 
 	fgw_func_reg(obj, "symbol_name_to_component_name", target_spice_sym2comp);
 	fgw_func_reg(obj, "compile_port", target_spice_compile_port);
+	fgw_func_reg(obj, "compile_component0", target_spice_compile_component0);
 	fgw_func_reg(obj, "compile_component1", target_spice_compile_component1);
 	fgw_func_reg(obj, "compile_project_before", target_spice_compile_project_before);
 	fgw_func_reg(obj, "compile_project_after", target_spice_compile_project_after);
@@ -775,7 +806,8 @@ static int on_load(fgw_obj_t *obj, const char *filename, const char *opts)
 	ctx->high_parser->parse = spicelib_parse;
 	ctx->high_parser->free_payload = spicelib_free_payload;
 
-	global_spicelib_ctx = ctx;
+	if (global_spicelib_ctx == NULL)
+		global_spicelib_ctx = ctx;
 
 
 	return 0;
