@@ -329,15 +329,32 @@ fgw_error_t csch_act_BufferSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (fn == NULL) {
 		static char *default_file = NULL;
 		const char *ext = ".*";
+		const char *title, *expl;
 
 		if (cmd == F_Symbol) {
 			default_file = rnd_strdup("sym.ry");
 			ext = ".ry";
 		}
 
-		fn = rnd_hid_fileselect(rnd_gui, "Save group from buffer...",
-			"Choose a file to save the group to,\nfrom the paste buffer.\n",
-			default_file, ext, NULL, "grp", 0, NULL);
+		switch(cmd) {
+			case F_Symbol:
+				title = "Save symbol from buffer...";
+				expl = "Choose a file to save the symbol (group) to,\nfrom the paste buffer.\n";
+				break;
+
+			case F_All:
+				title = "Save whole buffer...";
+				expl = "Choose a file to save the whole paste buffer to.\n";
+				break;
+
+			case F_Group:
+			default:
+				title = "Save group from buffer...";
+				expl = "Choose a file to save the group to,\nfrom the paste buffer.\n";
+				break;
+		}
+
+		fn = rnd_hid_fileselect(rnd_gui, title, expl, default_file, ext, NULL, "grp", 0, NULL);
 		if (default_file != NULL) {
 			free(default_file);
 			default_file = NULL;
@@ -366,7 +383,7 @@ fgw_error_t csch_act_BufferSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					}
 				}
 				if (grp != NULL)
-					rv = csch_save_grp(grp, fn, fmt);
+					rv = csch_save_grp(grp, fn, fmt, 1);
 			}
 			break;
 		case F_All:
