@@ -34,6 +34,7 @@
 #include <librnd/core/vtc0.h>
 #include <librnd/core/compat_misc.h>
 
+#include <libcschem/abstract.h>
 #include <libcschem/concrete.h>
 #include <libcschem/cnc_grp.h>
 #include <libcschem/cnc_line.h>
@@ -45,6 +46,7 @@
 #include <libcschem/non_graphical.h>
 #include <libcschem/util_wirenet.h>
 #include <libcschem/event.h>
+#include <libcschem/project.h>
 
 #include <gengeo2d/xform.h>
 
@@ -57,6 +59,7 @@ static const char draw_cookie[] = "sch-rnd/draw.c";
 
 typedef struct {
 	csch_sheet_t *sheet;
+	csch_abstract_t *abst;
 	rnd_hid_gc_t gc;
 	vtp0_t objlist;
 	rnd_xform_t *xform;
@@ -324,7 +327,7 @@ static csch_rtree_dir_t predraw_layer_obj(void *ctx_, void *obj_, const csch_rtr
 
 }
 
-static void draw_grp_meta(draw_ctx_t *ctx, csch_cgrp_t *grp)
+static void draw_grp_meta(draw_ctx_t *ctx, csch_cgrp_t *grp, int selected)
 {
 	int use_local = (ctx->xform != NULL) && ctx->xform->use_local_vis;
 	int vis_meta_sym = use_local ? ctx->xform->local_vis[CSCH_DSPLY_SYMBOL_META] : csch_layer_vis[CSCH_DSPLY_SYMBOL_META];
@@ -358,6 +361,75 @@ static void draw_grp_meta(draw_ctx_t *ctx, csch_cgrp_t *grp)
 		rnd_render->draw_line(ctx->gc, C2P(grp->x - 100), C2P(grp->y - 100), C2P(grp->x + 100), C2P(grp->y + 100));
 		rnd_render->draw_line(ctx->gc, C2P(grp->x + 100), C2P(grp->y - 100), C2P(grp->x - 100), C2P(grp->y + 100));
 	}
+
+	/* draw omit and dnp */
+	if ((ctx->abst != NULL) && (grp->role == CSCH_ROLE_SYMBOL) && (grp->hdr.bbox.x1 < grp->hdr.bbox.x2) && (grp->aid.used > 0)) {
+		int omit = 0, dnp = 0;
+		csch_ahdr_t *aobj;
+
+		TODO("hierarchic: revise this");
+		/* for now take only the first abstract's flag; in a more complicated
+		   situation in hierarchic design, the attributes may differ from
+		   abstract obj to abstract obj derived from the same concrete! */
+		aobj = htip_get(&ctx->abst->aid2obj, grp->aid.array[0]);
+		omit = aobj != NULL ? aobj->omit : 0;
+		dnp = aobj != NULL ? aobj->dnp : 0;
+
+		if (omit || dnp) {
+			rnd_render->set_color(ctx->gc, (selected ? &conf_core.appearance.color.selected_stroke : &conf_core.appearance.color.symbol_meta_embed));
+			rnd_hid_set_line_cap(ctx->gc, rnd_cap_round);
+			rnd_hid_set_line_width(ctx->gc, -2);
+		}
+
+		if (dnp) {
+			static void *f = NULL;
+			csch_coord_t cx = (grp->hdr.bbox.x1 + grp->hdr.bbox.x2)/2;
+			csch_coord_t cy = (grp->hdr.bbox.y1 + grp->hdr.bbox.y2)/2;
+
+			if (f == NULL)
+				f = sch_rnd_font_lookup("sans", "regular");
+
+			sch_rnd_render_text_string(ctx->gc, f, C2P(cx-2500), C2P(cy+2000), 2, (unsigned char *)"DNP");
+		}
+
+		if (omit) {
+			rnd_render->draw_line(ctx->gc, C2P(grp->hdr.bbox.x1), C2P(grp->hdr.bbox.y1), C2P(grp->hdr.bbox.x2), C2P(grp->hdr.bbox.y2));
+			rnd_render->draw_line(ctx->gc, C2P(grp->hdr.bbox.x1), C2P(grp->hdr.bbox.y2), C2P(grp->hdr.bbox.x2), C2P(grp->hdr.bbox.y1));
+		}
+	}
+
+	if ((ctx->abst != NULL) && (grp->role == CSCH_ROLE_WIRE_NET) && (grp->aid.used > 0)) {
+		int omit = 0;
+		csch_ahdr_t *aobj;
+
+		TODO("hierarchic: revise this");
+		/* for now take only the first abstract's flag; in a more complicated
+		   situation in hierarchic design, the attributes may differ from
+		   abstract obj to abstract obj derived from the same concrete! */
+		aobj = htip_get(&ctx->abst->aid2obj, grp->aid.array[0]);
+		omit = (aobj != NULL) ? aobj->omit : 0;
+
+		if (omit) {
+			htip_entry_t *e;
+
+			rnd_render->set_color(ctx->gc, (selected ? &conf_core.appearance.color.selected_stroke : &conf_core.appearance.color.symbol_meta_embed));
+			rnd_hid_set_line_cap(ctx->gc, rnd_cap_round);
+			rnd_hid_set_line_width(ctx->gc, -2);
+
+			for(e = htip_first(&grp->id2obj); e != NULL; e = htip_next(&grp->id2obj, e)) {
+				csch_line_t *line = e->value;
+				csch_coord_t cx, cy, len = 500;
+
+				if (line->hdr.type != CSCH_CTYPE_LINE) continue;
+				if ((line->inst.c.p1.x == line->inst.c.p2.x) && (line->inst.c.p1.y == line->inst.c.p2.y)) continue;
+
+				cx = (line->inst.c.p1.x + line->inst.c.p2.x)/2;
+				cy = (line->inst.c.p1.y + line->inst.c.p2.y)/2;
+				rnd_render->draw_line(ctx->gc, C2P(cx-len), C2P(cy-len), C2P(cx+len), C2P(cy+len));
+				rnd_render->draw_line(ctx->gc, C2P(cx-len), C2P(cy+len), C2P(cx+len), C2P(cy-len));
+			}
+		}
+	}
 }
 
 static csch_rtree_dir_t collect_layer_obj_fill(void *ctx_, void *obj_, const csch_rtree_box_t *box)
@@ -442,7 +514,7 @@ static csch_rtree_dir_t draw_layer_obj_stroke(void *ctx_, void *obj_, const csch
 		case CSCH_CTYPE_GRP:
 		case CSCH_CTYPE_GRP_REF:
 			/* no need to draw groups since we are working from rtree, but need to draw meta */
-			draw_grp_meta(ctx, (csch_cgrp_t *)obj);
+			draw_grp_meta(ctx, (csch_cgrp_t *)obj, sel);
 			break;
 
 		case CSCH_CTYPE_PEN:
@@ -522,11 +594,14 @@ RND_INLINE void sch_rnd_draw_sheet_graphical(csch_sheet_t *sheet, rnd_hid_gc_t g
 {
 	int n;
 	csch_rtree_box_t bb;
+	csch_project_t *prj = (csch_project_t *)sheet->hidlib.project;
 	draw_ctx_t ctx = {0};
 
 	ctx.sheet = sheet;
 	ctx.gc = gc;
 	ctx.xform = xform_caller;
+	if (prj != NULL)
+		ctx.abst = prj->abst;
 
 	bb.x1 = P2C(region->view.X1); bb.y1 = P2C(region->view.Y1);
 	bb.x2 = P2C(region->view.X2); bb.y2 = P2C(region->view.Y2);
