@@ -5,6 +5,7 @@
 */
 
 action_entry(All)
+action_entry(AllProject)
 action_entry(Any)
 action_entry(Auto)
 action_entry(Buffer)
@@ -22,6 +23,7 @@ action_entry(Poly)
 action_entry(Polygon)
 action_entry(Project)
 action_entry(Selected)
+action_entry(SelectedProject)
 action_entry(Sheet)
 action_entry(Sym)
 action_entry(Symbol)
