@@ -168,9 +168,11 @@ int sch_rnd_project_view_lib2lht(csch_view_t *view)
 	return 0;
 }
 
-static int project_create_postproc(csch_project_t *prj, const char *apname, int copy_views)
+static int project_create_postproc(csch_project_t *prj, const char *apname, int load, int copy_views)
 {
-	rnd_conf_load_as(RND_CFR_PROJECT, apname, 0);
+	if (load)
+		rnd_conf_load_as(RND_CFR_PROJECT, apname, 0);
+
 	rnd_conf_lht_get_first(RND_CFR_PROJECT, 1);
 
 	if (copy_views) { /* copy all existing views into the new project file */
@@ -186,6 +188,8 @@ static int project_create_postproc(csch_project_t *prj, const char *apname, int
 	return 0;
 }
 
+extern lht_doc_t *rnd_conf_main_root[RND_CFR_max_alloc];
+
 int sch_rnd_project_create_file_for_sheet_gui(csch_sheet_t *sheet)
 {
 	gds_t tmp = {0};
@@ -200,6 +204,10 @@ int sch_rnd_project_create_file_for_sheet_gui(csch_sheet_t *sheet)
 		return -1;
 	}
 
+	/* do not create it if it's already there */
+	if (rnd_file_readable(&sheet->hidlib, pname))
+		return 0;
+
 	gds_append_str(&tmp, "Do you want to create a project file ");
 	gds_append_str(&tmp, pname);
 	gds_append(&tmp, '?');
@@ -210,7 +218,7 @@ int sch_rnd_project_create_file_for_sheet_gui(csch_sheet_t *sheet)
 
 	apname = rnd_strdup(pname);
 	if (rnd_conf_lht_get_first(RND_CFR_PROJECT, 0) == NULL)
-		rnd_conf_reset(RND_CFR_PROJECT, apname);
+		lht_dom_loc_newfile(rnd_conf_main_root[RND_CFR_PROJECT], apname);
 
 	/* create a new project file */
 	if (sch_rnd_project_create_file_(&sheet->hidlib, pname) != 0) {
@@ -218,7 +226,7 @@ int sch_rnd_project_create_file_for_sheet_gui(csch_sheet_t *sheet)
 		return -1;
 	}
 
-	if (project_create_postproc(prj, apname, 1) != 0) {
+	if (project_create_postproc(prj, apname, 0, 1) != 0) {
 		free(apname);
 		return -1;
 	}
@@ -274,7 +282,7 @@ int sch_rnd_project_create_file(rnd_design_t *dsg, const char *pname, csch_proje
 	for(n = 0; n < prj->hdr.designs.used; n++) {
 		csch_sheet_t *sh = prj->hdr.designs.array[n];
 		csch_sheet_t *old = sch_rnd_multi_switch_to(sh);
-		project_create_postproc(prj, realp, (orig == NULL));
+		project_create_postproc(prj, realp, 1, (orig == NULL));
 		if (orig == NULL) {
 			orig = old;
 			first = sh;
@@ -338,14 +346,6 @@ int sch_rnd_project_del_view(csch_sheet_t *sheet, long idx, int silent)
 	return 0;
 }
 
-void sch_rnd_project_flush(void)
-{
-	csch_sheet_t *sheet = (csch_sheet_t *)rnd_multi_get_current();
-
-	rnd_conf_makedirty(RND_CFR_PROJECT);
-	rnd_conf_save_file(&sheet->hidlib, NULL,  sheet->hidlib.loadname, RND_CFR_PROJECT, NULL);
-}
-
 void sch_rnd_project_views_save(csch_sheet_t *sheet)
 {
 	rnd_conf_merge_all("compile/views");
