@@ -110,7 +110,7 @@ void sch_rnd_select_click(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y)
 
 	if (csch_chdr_is_selected(obj)) {
 		if (rnd_gui->shift_is_pressed(rnd_gui))
-			csch_cobj_unselect(sheet, obj);
+			csch_chdr_unselect_wp(obj);
 		else
 			sch_rnd_select_add_obj(sheet, obj, 1, 0);
 	}
